
.dijitReset {
	
	margin:0;
	border:0;
	padding:0;
	line-height:normal;
	font: inherit;
	color: inherit;
}
.dijit_a11y .dijitReset {
	-moz-appearance: none; 
}
.dijitInline {
	
	display:inline-block;			
	#zoom: 1; 
	#display:inline; 
	border:0;
	padding:0;
	vertical-align:middle;
	#vertical-align: auto;	
}
table.dijitInline {
	
	display:inline-table;
	box-sizing: content-box; -moz-box-sizing: content-box;
}
.dijitHidden {
	
	display: none !important;
}
.dijitVisible {
	
	display: block !important;	
	position: relative;			
}
.dijitInputContainer {
	
	#zoom: 1;
	overflow: hidden;
	float: none !important; 
	position: relative;
	vertical-align: middle;
	#display: inline;
}
.dj_ie input.dijitTextBox,
.dj_ie .dijitTextBox input {
	font-size: 100%;
}
.dijitTextBox .dijitSpinnerButtonContainer,
.dijitTextBox .dijitArrowButtonContainer,
.dijitTextBox .dijitValidationContainer {
	float: right;
	text-align: center;
}
.dijitTextBox input.dijitInputField {
	
	padding-left: 0 !important;
	padding-right: 0 !important;
}
.dijitTextBox .dijitValidationContainer {
	display: none;
}
.dijitTeeny {
	font-size:1px;
	line-height:1px;
}
.dijitOffScreen {
	position: absolute;
	left: 50%;
	top: -10000px;
}
.dijitPopup {
	position: absolute;
	background-color: transparent;
	margin: 0;
	border: 0;
	padding: 0;
}
.dijitPositionOnly {
	
	padding: 0 !important;
	border: 0 !important;
	background-color: transparent !important;
	background-image: none !important;
	height: auto !important;
	width: auto !important;
}
.dijitNonPositionOnly {
	
	float: none !important;
	position: static !important;
	margin: 0 0 0 0 !important;
	vertical-align: middle !important;
}
.dijitBackgroundIframe {
	
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	z-index: -1;
	border: 0;
	padding: 0;
	margin: 0;
}
.dijitDisplayNone {
	
	display:none !important;
}
.dijitContainer {
	
	overflow: hidden;	
}
.dijit_a11y .dijitIcon,
.dijit_a11y div.dijitArrowButtonInner, 
.dijit_a11y span.dijitArrowButtonInner,
.dijit_a11y img.dijitArrowButtonInner,
.dijit_a11y .dijitCalendarIncrementControl,
.dijit_a11y .dijitTreeExpando {
	
	display: none;
}
.dijitSpinner div.dijitArrowButtonInner {
	display: block; 
}
.dijit_a11y .dijitA11ySideArrow {
	display: inline !important; 
	cursor: pointer;
}
.dijit_a11y .dijitCalendarDateLabel {
	padding: 1px;
	border: 0px !important;
}
.dijit_a11y .dijitCalendarSelectedDate .dijitCalendarDateLabel {
	border-style: solid !important;
	border-width: 1px !important;
	padding: 0;
}
.dijit_a11y .dijitCalendarDateTemplate {
	padding-bottom: 0.1em !important;	
	border: 0px !important;
}
.dijit_a11y .dijitButtonNode {
	border: black outset medium !important;
	
	padding: 0 !important;
}
.dijit_a11y .dijitButtonContents{
	margin: 0.15em; 
}
.dijit_a11y .dijitTextBoxReadOnly .dijitInputField,
.dijit_a11y .dijitTextBoxReadOnly .dijitButtonNode {
	border-style: outset!important;
	border-width: medium!important;
	border-color: #999 !important;
	color:#999 !important;
}
.dijitButtonNode * {
	vertical-align: middle;
}
.dijitButtonNode .dijitArrowButtonInner {
	
	background: no-repeat center;
	width: 12px;
	height: 12px;
	direction: ltr; 
}
.dijitLeft {
	
	background-position:left top;
	background-repeat:no-repeat;
}
.dijitStretch {
	
	white-space:nowrap;			
	background-repeat:repeat-x;
}
.dijitRight {
	
	#display:inline;				
	background-position:right top;
	background-repeat:no-repeat;
}
.dj_gecko .dijit_a11y .dijitButtonDisabled .dijitButtonNode {
	opacity: 0.5;
}
.dijitToggleButton,
.dijitButton,
.dijitDropDownButton,
.dijitComboButton {
	
	margin: 0.2em;
	vertical-align: middle;
}
.dijitButtonContents {
	display: block;		
}
td.dijitButtonContents {
	display: table-cell;	
}
.dijitButtonNode img {
	
	vertical-align:middle;
	
}
.dijitToolbar .dijitComboButton {
	
	border-collapse: separate;
}
.dijitToolbar .dijitToggleButton,
.dijitToolbar .dijitButton,
.dijitToolbar .dijitDropDownButton,
.dijitToolbar .dijitComboButton {
	margin: 0;
}
.dijitToolbar .dijitButtonContents {
	
	padding: 1px 2px;
}
.dj_webkit .dijitToolbar .dijitDropDownButton {
	padding-left: 0.3em;
}
.dj_gecko .dijitToolbar .dijitButtonNode::-moz-focus-inner {
	padding:0;
}
.dijitButtonNode {
	
	border:1px solid gray;
	margin:0;
	line-height:normal;
	vertical-align: middle;
	#vertical-align: auto;
	text-align:center;
	white-space: nowrap;
}
.dj_webkit .dijitSpinner .dijitSpinnerButtonContainer {
	
	line-height:inherit;
}
.dijitTextBox .dijitButtonNode {
	border-width: 0;
}
.dijitButtonNode,
.dijitButtonNode * {
	cursor: pointer;
}
.dj_ie .dijitButtonNode {
	
	zoom: 1;
}
.dj_ie .dijitButtonNode button {
	
	overflow: visible;
}
div.dijitArrowButton {
	float: right;
}
.dijitTextBox {
	border: solid black 1px;
	#overflow: hidden; 
	width: 15em;	
	vertical-align: middle;
}
.dijitTextBoxReadOnly,
.dijitTextBoxDisabled {
	color: gray;
}
.dj_webkit .dijitTextBoxDisabled input {
	color: #eee; 
}
.dj_webkit textarea.dijitTextAreaDisabled {
	color: #333; 
}
.dj_gecko .dijitTextBoxReadOnly input.dijitInputField, 
.dj_gecko .dijitTextBoxDisabled input {
	-moz-user-input: none; 
}
.dijitPlaceHolder {
	
	color: #AAAAAA;
	font-style: italic;
	position: absolute;
	top: 0;
	left: 0;
	#filter: ""; 
}
.dijitTimeTextBox {
	width: 8em;
}
.dijitTextBox input:focus {
	outline: none;	
}
.dijitTextBoxFocused {
	outline: 5px -webkit-focus-ring-color;
}
.dijitTextBox input {
	float: left; 
}
.dijitInputInner {
	
	border:0 !important;
	vertical-align:middle !important;
	background-color:transparent !important;
	width:100% !important;
	
	padding-left: 0 !important;
	padding-right: 0 !important;
	margin-left: 0 !important;
	margin-right: 0 !important;
}
.dijit_a11y .dijitTextBox input {
	margin: 0 !important;
}
.dijitTextBoxError input.dijitValidationInner,
.dijitTextBox input.dijitArrowButtonInner {
	
	text-indent: -1em !important;
	direction: ltr !important;
	text-align: left !important;
	height: auto !important;
	#text-indent: 0 !important;
	#letter-spacing: -5em !important;
	#text-align: right !important;
}
.dj_ie .dijitTextBox input,
.dj_ie input.dijitTextBox {
	overflow-y: visible; 
	line-height: normal; 
}
.dj_ie7 .dijitTextBox input.dijitValidationInner,
.dj_ie7 .dijitTextBox input.dijitArrowButtonInner {
	line-height: 86%; 
}
.dj_ie6 .dijitTextBox input,
.dj_ie6 input.dijitTextBox,
.dj_iequirks .dijitTextBox input.dijitValidationInner,
.dj_iequirks .dijitTextBox input.dijitArrowButtonInner,
.dj_iequirks .dijitTextBox input.dijitSpinnerButtonInner,
.dj_iequirks .dijitTextBox input.dijitInputInner,
.dj_iequirks input.dijitTextBox {
	line-height: 100%; 
}
.dijit_a11y input.dijitValidationInner,
.dijit_a11y input.dijitArrowButtonInner {
	
	text-indent: 0 !important;
	width: 1em !important;
	#text-align: left !important;
}
.dijitTextBoxError .dijitValidationContainer {
	display: inline;
	cursor: default;
}
.dijitSpinner .dijitSpinnerButtonContainer,
.dijitComboBox .dijitArrowButtonContainer {
	
	border-width: 0 0 0 1px !important; 
}
.dijitToolbar .dijitComboBox .dijitArrowButtonContainer {
	
	border-width: 0 !important;
}
.dijitComboBoxMenu {
	
	list-style-type: none;
}
.dijitSpinner .dijitSpinnerButtonContainer .dijitButtonNode {
	
	border-width: 0;
}
.dj_ie .dijit_a11y .dijitSpinner .dijitSpinnerButtonContainer .dijitButtonNode {
	clear: both; 
}
.dj_ie .dijitToolbar .dijitComboBox {
	
	vertical-align: middle;
}
.dijitTextBox .dijitSpinnerButtonContainer {
	width: 1em;
	position: relative !important;
	overflow: hidden;
}
.dijitSpinner .dijitSpinnerButtonInner {
	width:1em;
	visibility:hidden !important; 
	overflow-x:hidden;
}
.dijitComboBox .dijitButtonNode,
.dijitSpinnerButtonContainer .dijitButtonNode {
	border-width: 0;
}
.dijit_a11y .dijitSpinnerButtonContainer .dijitButtonNode {
	border: 0 none !important;
}
.dijit_a11y .dijitTextBox .dijitSpinnerButtonContainer,
.dijit_a11y .dijitSpinner .dijitArrowButtonInner,
.dijit_a11y .dijitSpinnerButtonContainer input {
	width: 1em !important;
}
.dijit_a11y .dijitSpinner .dijitArrowButtonInner {
	margin: 0 auto !important; 
}
.dj_ie .dijit_a11y .dijitSpinner .dijitArrowButtonInner .dijitInputField {
	padding-left: 0.3em !important;
	padding-right: 0.3em !important;
	margin-left: 0.3em !important;
	margin-right: 0.3em !important;
	width: 1.4em !important;
}
.dj_ie7 .dijit_a11y .dijitSpinner .dijitArrowButtonInner .dijitInputField {
	padding-left: 0 !important; 
	padding-right: 0 !important;
	width: 1em !important;
}
.dj_ie6 .dijit_a11y .dijitSpinner .dijitArrowButtonInner .dijitInputField {
	margin-left: 0.1em !important;
	margin-right: 0.1em !important;
	width: 1em !important;
}
.dj_iequirks .dijit_a11y .dijitSpinner .dijitArrowButtonInner .dijitInputField {
	margin-left: 0 !important;
	margin-right: 0 !important;
	width: 2em !important;
}
.dijitSpinner .dijitSpinnerButtonContainer .dijitArrowButton {
	
	padding: 0;
	position: absolute !important;
	right: 0;
	float: none;
	height: 50%;
	width: 100%;
	bottom: auto;
	left: 0;
	right: auto;
}
.dj_iequirks .dijitSpinner .dijitSpinnerButtonContainer .dijitArrowButton {
	width: auto;
}
.dijit_a11y .dijitSpinnerButtonContainer .dijitArrowButton {
	overflow: visible !important;
}
.dijitSpinner .dijitSpinnerButtonContainer .dijitDownArrowButton {
	top: 50%;
	border-top-width: 1px !important;
}
.dijitSpinner .dijitSpinnerButtonContainer .dijitUpArrowButton {
	#bottom: 50%;	
	top: 0;
}
.dijitSpinner .dijitArrowButtonInner {
	margin: auto;
	overflow-x: hidden;
	height: 100% !important;
}
.dj_iequirks .dijitSpinner .dijitArrowButtonInner {
	height: auto !important;
}
.dijitSpinner .dijitArrowButtonInner .dijitInputField {
	-moz-transform: scale(0.5);
	-moz-transform-origin: center top;
	-webkit-transform: scale(0.5);
	-webkit-transform-origin: center top;
	-o-transform: scale(0.5);
	-o-transform-origin: center top;
	transform: scale(0.5);
	transform-origin: left top;
	padding-top: 0;
	padding-bottom: 0;
	padding-left: 0 !important;
	padding-right: 0 !important;
	width: 100%;
}
.dj_ie .dijitSpinner .dijitArrowButtonInner .dijitInputField {
	zoom: 50%; 
}
.dijitSpinner .dijitSpinnerButtonContainer .dijitArrowButtonInner {
	overflow: hidden;
}
.dijit_a11y .dijitSpinner .dijitSpinnerButtonContainer .dijitArrowButton {
	width: 100%;
}
.dj_iequirks .dijit_a11y .dijitSpinner .dijitSpinnerButtonContainer .dijitArrowButton {
	width: 1em; 
}
.dijitSpinner .dijitArrowButtonInner .dijitInputField {
	visibility: hidden;
}
.dijit_a11y .dijitSpinner .dijitArrowButtonInner .dijitInputField {
	vertical-align:top;
	visibility: visible;
}
.dijit_a11y .dijitSpinnerButtonContainer {
	width: 1em;
}
.dijit_a11y .dijitSpinnerButtonContainer .dijitButtonNode {
	border-width: 1px 0 0 0;
	border-style: solid !important;
}
.dijitCheckBox,
.dijitRadio,
.dijitCheckBoxInput {
	padding: 0;
	border: 0;
	width: 16px;
	height: 16px;
	background-position:center center;
	background-repeat:no-repeat;
	overflow: hidden;
}
.dijitCheckBox input,
.dijitRadio input {
	margin: 0;
	padding: 0;
	display: block;
}
.dijitCheckBoxInput {
	
	opacity: 0.01;
}
.dj_ie .dijitCheckBoxInput {
	filter: alpha(opacity=0);
}
.dijit_a11y .dijitCheckBox,
.dijit_a11y .dijitRadio {
	
	width: auto !important;
	height: auto !important;
}
.dijit_a11y .dijitCheckBoxInput {
	opacity: 1;
	filter: none;
	width: auto;
	height: auto;
}
.dijit_a11y .dijitFocusedLabel {
	
	border: 1px dotted;
	outline: 0px !important;
}
.dijitProgressBarEmpty {
	
	position:relative;overflow:hidden;
	border:1px solid black; 	
	z-index:0;			
}
.dijitProgressBarFull {
	
	position:absolute;
	overflow:hidden;
	z-index:-1;
	top:0;
	width:100%;
}
.dj_ie6 .dijitProgressBarFull {
	height:1.6em;
}
.dijitProgressBarTile {
	
	position:absolute;
	overflow:hidden;
	top:0;
	left:0;
	bottom:0;
	right:0;
	margin:0;
	padding:0;
	width: 100%;    
	height:auto;
	background-color:#aaa;
	background-attachment: fixed;
}
.dijit_a11y .dijitProgressBarTile {
	
	border-width:2px;
	border-style:solid;
	background-color:transparent !important;
}
.dj_ie6 .dijitProgressBarTile {
	
	position:static;
	
	height:1.6em;
}
.dijitProgressBarIndeterminate .dijitProgressBarTile {
	
}
.dijitProgressBarIndeterminateHighContrastImage {
	display:none;
}
.dijit_a11y .dijitProgressBarIndeterminate .dijitProgressBarIndeterminateHighContrastImage {
	display:block;
	position:absolute;
	top:0;
	bottom:0;
	margin:0;
	padding:0;
	width:100%;
	height:auto;
}
.dijitProgressBarLabel {
	display:block;
	position:static;
	width:100%;
	text-align:center;
	background-color:transparent !important;
}
.dijitTooltip {
	position: absolute;
	z-index: 2000;
	display: block;
	
	left: 0;
	top: -10000px;
	overflow: visible;
}
.dijitTooltipContainer {
	border: solid black 2px;
	background: #b8b5b5;
	color: black;
	font-size: small;
}
.dijitTooltipFocusNode {
	padding: 2px 2px 2px 2px;
}
.dijitTooltipConnector {
	position: absolute;
}
.dijit_a11y .dijitTooltipConnector {
	display: none;	
}
.dijitTooltipData {
	display:none;
}
.dijitLayoutContainer {
	position: relative;
	display: block;
	overflow: hidden;
}
.dijitAlignTop,
.dijitAlignBottom,
.dijitAlignLeft,
.dijitAlignRight {
	position: absolute;
	overflow: hidden;
}
body .dijitAlignClient { position: absolute; }
.dijitBorderContainer, .dijitBorderContainerNoGutter {
	position:relative;
	overflow: hidden;
}
.dijitBorderContainerPane,
.dijitBorderContainerNoGutterPane {
	position: absolute !important;	
	z-index: 2;		
}
.dijitBorderContainer > .dijitTextArea {
	
	resize: none;
}
.dijitGutter {
	
	position: absolute;
	font-size: 1px;		
}
.dijitSplitter {
	position: absolute;
	overflow: hidden;
	z-index: 10;		
	background-color: #fff;
	border-color: gray;
	border-style: solid;
	border-width: 0;
}
.dj_ie .dijitSplitter {
	z-index: 1;	
}
.dijitSplitterActive {
	z-index: 11 !important;
}
.dijitSplitterCover {
	position:absolute;
	z-index:-1;
	top:0;
	left:0;
	width:100%;
	height:100%;
}
.dijitSplitterCoverActive {
	z-index:3 !important;
}
.dj_ie .dijitSplitterCover {
	background: white;
	filter: alpha(opacity=0);
}
.dijitSplitterH {
	height: 7px;
	border-top:1px;
	border-bottom:1px;
	cursor: row-resize;
}
.dijitSplitterV {
	width: 7px;
	border-left:1px;
	border-right:1px;
	cursor: col-resize;
}
.dijitSplitContainer {
	position: relative;
	overflow: hidden;
	display: block;
}
.dj_ff3 .dijit_a11y div.dijitSplitter:focus {
	outline-style:dotted;
	outline-width: 2px;
}
.dijitSplitPane {
	position: absolute;
}
.dijitSplitContainerSizerH,
.dijitSplitContainerSizerV {
	position:absolute;
	font-size: 1px;
	background-color: ThreeDFace;
	border: 1px solid;
	border-color: ThreeDHighlight ThreeDShadow ThreeDShadow ThreeDHighlight;
	margin: 0;
}
.dijitSplitContainerSizerH .thumb, .dijitSplitterV .dijitSplitterThumb {
	overflow:hidden;
	position:absolute;
	top:49%;
}
.dijitSplitContainerSizerV .thumb, .dijitSplitterH .dijitSplitterThumb {
	position:absolute;
	left:49%;
}
.dijitSplitterShadow,
.dijitSplitContainerVirtualSizerH,
.dijitSplitContainerVirtualSizerV {
	font-size: 1px;
	background-color: ThreeDShadow;
	-moz-opacity: 0.5;
	opacity: 0.5;
	filter: Alpha(Opacity=50);
	margin: 0;
}
.dijitSplitContainerSizerH, .dijitSplitContainerVirtualSizerH {
	cursor: col-resize;
}
.dijitSplitContainerSizerV, .dijitSplitContainerVirtualSizerV {
	cursor: row-resize;
}
.dijit_a11y .dijitSplitterH {
	border-top:1px solid #d3d3d3 !important;
	border-bottom:1px solid #d3d3d3 !important;
}
.dijit_a11y .dijitSplitterV {
	border-left:1px solid #d3d3d3 !important;
	border-right:1px solid #d3d3d3 !important;
}
.dijitContentPane {
	display: block;
	overflow: auto;	
}
.dijitContentPaneSingleChild {
	
	overflow: hidden;
}
.dijitContentPaneLoading .dijitIconLoading,
.dijitContentPaneError .dijitIconError {
	margin-right: 9px;
}
.dijitTitlePane {
	display: block;
	overflow: hidden;
}
.dijitTitlePaneTitle {
	cursor: pointer;
}
.dijitFixedOpen, .dijitFixedClosed {
	
	cursor: default;
}
.dijitTitlePaneTitle * {
	vertical-align: middle;
}
.dijitTitlePane .dijitArrowNodeInner {
	
	display: none;
}
.dijit_a11y .dijitTitlePane .dijitArrowNodeInner {
	
	display:inline !important;
	font-family: monospace;		
}
.dijit_a11y .dijitTitlePane .dijitArrowNode {
	
	display:none;
}
.dj_ie6 .dijitTitlePaneContentOuter,
.dj_ie6 .dijitTitlePane .dijitTitlePaneTitle {
	
	zoom: 1;
}
.dijitColorPalette {
	border: 1px solid #999;
	background: #fff;
	position: relative;
}
.dijitColorPalette .dijitPaletteTable {
	
	padding: 2px 3px 3px 3px;
	position: relative;
	overflow: hidden;
	outline: 0;
	border-collapse: separate;
}
.dj_ie6 .dijitColorPalette .dijitPaletteTable,
.dj_ie7 .dijitColorPalette .dijitPaletteTable,
.dj_iequirks .dijitColorPalette .dijitPaletteTable {
	
	padding: 0;
	margin: 2px 3px 3px 3px;
}
.dijitColorPalette .dijitPaletteCell {
	
	font-size: 1px;
	vertical-align: middle;
	text-align: center;
	background: none;
}
.dijitColorPalette .dijitPaletteImg {
	
	padding: 1px;		
	border: 1px solid #999;
	margin: 2px 1px;
	cursor: default;
	font-size: 1px;		
}
.dj_gecko .dijitColorPalette .dijitPaletteImg {
	padding-bottom: 0;	
}
.dijitColorPalette .dijitColorPaletteSwatch {
	
	width: 14px;
	height: 12px;
}
.dijitPaletteTable td {
		padding: 0;
}
.dijitColorPalette .dijitPaletteCell:hover .dijitPaletteImg {
	
	border: 1px solid #000;
}
.dijitColorPalette .dijitPaletteCell:active .dijitPaletteImg,
.dijitColorPalette .dijitPaletteTable .dijitPaletteCellSelected .dijitPaletteImg {
	border: 2px solid #000;
	margin: 1px 0;	
}
.dijit_a11y .dijitColorPalette .dijitPaletteTable,
.dijit_a11y .dijitColorPalette .dijitPaletteTable * {
	
	background-color: transparent !important;
}
.dijitAccordionContainer {
	border:1px solid #b7b7b7;
	border-top:0 !important;
}
.dijitAccordionTitle {
	cursor: pointer;
}
.dijitAccordionTitleSelected {
	cursor: default;
}
.dijitAccordionTitle .arrowTextUp,
.dijitAccordionTitle .arrowTextDown {
	display: none;
	font-size: 0.65em;
	font-weight: normal !important;
}
.dijit_a11y .dijitAccordionTitle .arrowTextUp,
.dijit_a11y .dijitAccordionTitleSelected .arrowTextDown {
	display: inline;
}
.dijit_a11y .dijitAccordionTitleSelected .arrowTextUp {
	display: none;
}
.dijitAccordionChildWrapper {
	
	overflow: hidden;
}
.dijitCalendarContainer {
	width: auto;	
}
.dijitCalendarContainer th, .dijitCalendarContainer td {
	padding: 0;
	vertical-align: middle;
}
.dijitCalendarYearLabel {
    white-space: nowrap;    
}
.dijitCalendarNextYear {
	margin:0 0 0 0.55em;
}
.dijitCalendarPreviousYear {
	margin:0 0.55em 0 0;
}
.dijitCalendarIncrementControl {
	vertical-align: middle;
}
.dijitCalendarIncrementControl,
.dijitCalendarDateTemplate,
.dijitCalendarMonthLabel,
.dijitCalendarPreviousYear,
.dijitCalendarNextYear {
	cursor: pointer;
}
.dijitCalendarDisabledDate {
	color: gray;
	text-decoration: line-through;
	cursor: default;
}
.dijitSpacer {
	
  	position: relative;
  	height: 1px;
  	overflow: hidden;
  	visibility: hidden;
}
.dijitCalendarMonthMenu .dijitCalendarMonthLabel {
	text-align:center;
}
.dijitMenu {
	border:1px solid black;
	background-color:white;
}
.dijitMenuTable {
	border-collapse:collapse;
	border-width:0;
	background-color:white;
}
.dj_webkit .dijitMenuTable td[colspan="2"]{
	border-right:hidden;
}
.dijitMenuItem {
	text-align: left;
	white-space: nowrap;
	padding:.1em .2em;
	cursor:pointer;
}
.dijitMenuPassive .dijitMenuItemHover,
.dijitMenuItemSelected {
	
	background-color:black;
	color:white;
}
.dijitMenuItemIcon, .dijitMenuExpand {
	background-repeat: no-repeat;
}
.dijitMenuItemDisabled * {
	
	opacity:0.5;
	cursor:default;
}
.dj_ie .dijit_a11y .dijitMenuItemDisabled,
.dj_ie .dijit_a11y .dijitMenuItemDisabled td,
.dj_ie .dijitMenuItemDisabled *,
.dj_ie .dijitMenuItemDisabled td {
	color:gray !important;
	filter: alpha(opacity=35);
}
.dijitMenuItemLabel {
	position: relative;
	vertical-align: middle;
}
.dijit_a11y .dijitMenuItemSelected {
	border: 1px dotted black !important;
}
.dj_ff3 .dijit_a11y .dijitMenuItem td {
	padding: 0 !important;
	background:none !important;
}
.dijit_a11y .dijitMenuItemSelected .dijitMenuItemLabel {
	border-width: 1px;
	border-style: solid;
}
.dj_ie8 .dijit_a11y .dijitMenuItemLabel {
	position:static;
}
.dijitMenuExpandA11y {
	display: none;
}
.dijit_a11y .dijitMenuExpandA11y {
	display: inline;
}
.dijitMenuSeparator td {
	border: 0;
	padding: 0;
}
.dijitMenuSeparatorTop {
	height: 50%;
	margin: 0;
	margin-top:3px;
	font-size: 1px;
}
.dijitMenuSeparatorBottom {
	height: 50%;
	margin: 0;
	margin-bottom:3px;
	font-size: 1px;
}
.dijitCheckedMenuItemIconChar {
	vertical-align: middle;
	visibility:hidden;
}
.dijitCheckedMenuItemChecked .dijitCheckedMenuItemIconChar {
	visibility: visible;
}
.dijit_a11y .dijitCheckedMenuItemIconChar {
	display:inline !important;
}
.dijit_a11y .dijitCheckedMenuItemIcon {
	display: none;
}
.dj_ie .dijit_a11y .dijitMenuBar .dijitMenuItem {
	
	margin: 0;
}
.dijitStackController .dijitToggleButtonChecked * {
	cursor: default;	
}
.dijitTabContainerNoLayout {
	width: 100%;	
}
.dijitTabContainerBottom-tabs,
.dijitTabContainerTop-tabs,
.dijitTabContainerLeft-tabs,
.dijitTabContainerRight-tabs {
	overflow: visible !important;  
}
.dijitTabContainerBottom-container,
.dijitTabContainerTop-container,
.dijitTabContainerLeft-container,
.dijitTabContainerRight-container {
	z-index:0;
	overflow: hidden;
	border: 1px solid black;
}
.nowrapTabStrip {
	width: 50000px;
	display: block;
	position: relative;
    text-align: left;  
}
.dijitTabListWrapper {
	overflow: hidden;
}
.dijit_a11y .tabStripButton img {
	
	display: none;
}
.dijitTabContainerTop-tabs {
	border-bottom: 1px solid black;
}
.dijitTabContainerTop-container {
	border-top: 0;
}
.dijitTabContainerLeft-tabs {
	border-right: 1px solid black;
	float: left;
}
.dijitTabContainerLeft-container {
	border-left: 0;
}
.dijitTabContainerBottom-tabs {
	border-top: 1px solid black;
}
.dijitTabContainerBottom-container {
	border-bottom: 0;
}
.dijitTabContainerRight-tabs {
	border-left: 1px solid black;
	float: left;
}
.dijitTabContainerRight-container {
	border-right: 0;
}
div.dijitTabDisabled, .dj_ie div.dijitTabDisabled {
	cursor: auto;
}
.dijitTab {
	position:relative;
	cursor:pointer;
	white-space:nowrap;
	z-index:3;
}
.dijitTab * {
	
	vertical-align: middle;
}
.dijitTabChecked {
	cursor: default;	
}
.dijitTabContainerTop-tabs .dijitTab {
	top: 1px;	
}
.dijitTabContainerBottom-tabs .dijitTab {
	top: -1px;	
}
.dijitTabContainerLeft-tabs .dijitTab {
	left: 1px;	
}
.dijitTabContainerRight-tabs .dijitTab {
	left: -1px;	
}
.dijitTabContainerTop-tabs .dijitTab,
.dijitTabContainerBottom-tabs .dijitTab {
	
	display:inline-block;			
	#zoom: 1; 
	#display:inline; 
}
.dijitTabInnerDiv {
	position:relative;
}
.tabStripButton {
	z-index: 12;
}
.dijitTabButtonDisabled .tabStripButton {
	display: none;
}
.dijitTabCloseButton {
	margin-left: 1em;
}
.dijitTabCloseText {
	display:none;
}
.dijitTab .tabLabel {
	
	min-height: 15px;
	display: inline-block;
}
.dijitNoIcon {
	
	display: none;
}
.dj_ie6 .dijitTab .dijitNoIcon {
	
	display: inline;
	height: 15px;
	width: 1px;
}
.dijit_a11y .dijitTabCloseButton {
	background-image: none !important;
	width: auto !important;
	height: auto !important;
}
.dijit_a11y .dijitTabCloseText {
	display: inline;
}
.dijitTabPane,
.dijitStackContainer-child,
.dijitAccordionContainer-child {
	
    border: none !important;
}
.dijitInlineEditBoxDisplayMode {
	border: 1px solid transparent;	
	cursor: text;
}
.dijit_a11y .dijitInlineEditBoxDisplayMode,
.dj_ie6 .dijitInlineEditBoxDisplayMode {
	
	border: none;
}
.dijitInlineEditBoxDisplayModeHover,
.dijit_a11y .dijitInlineEditBoxDisplayModeHover,
.dj_ie6 .dijitInlineEditBoxDisplayModeHover {
	
	background-color: #e2ebf2;
	border: solid 1px black;
}
.dijitInlineEditBoxDisplayModeDisabled {
	cursor: default;
}
.dijitTree {
	overflow: auto;	
}
.dijitTreeIndent {
	
	width: 19px;
}
.dijitTreeRow, .dijitTreeContent {
	white-space: nowrap;
}
.dijitTreeRow img {
	
	vertical-align: middle;
}
.dijitTreeContent {
    cursor: default;
}
.dijitExpandoText {
	display: none;
}
.dijit_a11y .dijitExpandoText {
	display: inline;
	padding-left: 10px;
	padding-right: 10px;
	font-family: monospace;
	border-style: solid;
	border-width: thin;
	cursor: pointer;
}
.dijitTreeLabel {
	margin: 0 4px;
}
.dijitDialog {
	position: absolute;
	z-index: 999;
	overflow: hidden;       
}
.dijitDialogTitleBar {
	cursor: move;
}
.dijitDialogFixed .dijitDialogTitleBar {
	cursor:default;
}
.dijitDialogCloseIcon {
	cursor: pointer;
}
.dijitDialogUnderlayWrapper {
	position: absolute;
	left: 0;
	top: 0;
	z-index: 998;
	display: none;
	background: transparent !important;
}
.dijitDialogUnderlay {
	background: #eee;
	opacity: 0.5;
}
.dj_ie .dijitDialogUnderlay {
	filter: alpha(opacity=50);
}
.dijit_a11y .dijitSpinnerButtonContainer,
.dijit_a11y .dijitDialog {
	opacity: 1 !important;
	background-color: white !important;
}
.dijitDialog .closeText {
	display:none;
	
	position:absolute;
}
.dijit_a11y .dijitDialog .closeText {
	display:inline;
}
.dijitSliderMoveable {
	z-index:99;
	position:absolute !important;
	display:block;
	vertical-align:middle;
}
.dijitSliderMoveableH {
	right:0;
}
.dijitSliderMoveableV {
	right:50%;
}
.dijit_a11y div.dijitSliderImageHandle,
.dijitSliderImageHandle {
	margin:0;
	padding:0;
	position:relative !important;
	border:8px solid gray;
	width:0;
	height:0;
	cursor: pointer;
}
.dj_iequirks .dijit_a11y .dijitSliderImageHandle {
	font-size: 0;
}
.dj_ie7 .dijitSliderImageHandle {
	overflow: hidden; 
}
.dj_ie7 .dijit_a11y .dijitSliderImageHandle {
	overflow: visible; 
}
.dijit_a11y .dijitSliderFocused .dijitSliderImageHandle {
	border:4px solid #000;
	height:8px;
	width:8px;
}
.dijitSliderImageHandleV {
	top:-8px;
	right: -50%;
}
.dijitSliderImageHandleH {
	left:50%;
	top:-5px;
	vertical-align:top;
}
.dijitSliderBar {
	border-style:solid;
	border-color:black;
	cursor: pointer;
}
.dijitSliderBarContainerV {
	position:relative;
	height:100%;
	z-index:1;
}
.dijitSliderBarContainerH {
	position:relative;
	z-index:1;
}
.dijitSliderBarH {
	height:4px;
	border-width:1px 0;
}
.dijitSliderBarV {
	width:4px;
	border-width:0 1px;
}
.dijitSliderProgressBar {
	background-color:red;
	z-index:1;
}
.dijitSliderProgressBarV {
	position:static !important;
	height:0;
	vertical-align:top;
	text-align:left;
}
.dijitSliderProgressBarH {
	position:absolute !important;
	width:0;
	vertical-align:middle;
	overflow:visible;
}
.dijitSliderRemainingBar {
	overflow:hidden;
	background-color:transparent;
	z-index:1;
}
.dijitSliderRemainingBarV {
	height:100%;
	text-align:left;
}
.dijitSliderRemainingBarH {
	width:100% !important;
}
.dijitSliderBumper {
	overflow:hidden;
	z-index:1;
}
.dijitSliderBumperV {
	width:4px;
	height:8px;
	border-width:0 1px;
}
.dijitSliderBumperH {
	width:8px;
	height:4px;
	border-width:1px 0;
}
.dijitSliderBottomBumper,
.dijitSliderLeftBumper {
	background-color:red;
}
.dijitSliderTopBumper,
.dijitSliderRightBumper {
	background-color:transparent;
}
.dijitSliderDecoration {
	text-align:center;
}
.dijitSliderDecorationC,
.dijitSliderDecorationV {
	position: relative; 
}
.dijitSliderDecorationH {
	width: 100%;
}
.dijitSliderDecorationV {
	height: 100%;
}
.dijitSliderButton {
	font-family:monospace;
	margin:0;
	padding:0;
	display:block;
}
.dijit_a11y .dijitSliderButtonInner {
	visibility:visible !important;
}
.dijitSliderButtonContainer {
	text-align:center;
	height:0;	
}
.dijitSliderButtonContainer * {
	cursor: pointer;
}
.dijitSlider .dijitButtonNode {
	padding:0;
	display:block;
}
.dijitRuleContainer {
	position:relative;
	overflow:visible;
}
.dijitRuleContainerV {
	height:100%;
	line-height:0;
	float:left;
	text-align:left;
}
.dj_opera .dijitRuleContainerV {
	line-height:2%;
}
.dj_ie .dijitRuleContainerV {
	line-height:normal;
}
.dj_gecko .dijitRuleContainerV {
	margin:0 0 1px 0; 
}
.dijitRuleMark {
	position:absolute;
	border:1px solid black;
	line-height:0;
	height:100%;
}
.dijitRuleMarkH {
	width:0;
	border-top-width:0 !important;
	border-bottom-width:0 !important;
	border-left-width:0 !important;
}
.dijitRuleLabelContainer {
	position:absolute;
}
.dijitRuleLabelContainerH {
	text-align:center;
	display:inline-block;
}
.dijitRuleLabelH {
	position:relative;
	left:-50%;
}
.dijitRuleLabelV {
	
	text-overflow: ellipsis;
	white-space: nowrap;
	overflow: hidden;
}
.dijitRuleMarkV {
	height:0;
	border-right-width:0 !important;
	border-bottom-width:0 !important;
	border-left-width:0 !important;
	width:100%;
	left:0;
}
.dj_ie .dijitRuleLabelContainerV {
	margin-top:-.55em;
}
.dijit_a11y .dijitSliderReadOnly,
.dijit_a11y .dijitSliderDisabled {
	opacity:0.6;
}
.dj_ie .dijit_a11y .dijitSliderReadOnly .dijitSliderBar,
.dj_ie .dijit_a11y .dijitSliderDisabled .dijitSliderBar {
	filter: alpha(opacity=40);
}
.dijit_a11y .dijitSlider .dijitSliderButtonContainer div {
	font-family: monospace; 
	font-size: 1em;
	line-height: 1em;
	height: auto;
	width: auto;
	margin: 0 4px;
}
.dijit_a11y .dijitButtonContents .dijitButtonText,
.dijit_a11y .dijitTab .tabLabel {
	display: inline !important;
}
.dijitTextArea {
	width:100%;
	overflow-y: auto;	
}
.dijitTextArea[cols] {
	width:auto; 
}
.dj_ie .dijitTextAreaCols {
	width:auto;
}
.dijitExpandingTextArea {
	
	resize: none;
}
.dijitToolbarSeparator {
	height: 18px;
	width: 5px;
	padding: 0 1px;
	margin: 0;
}
.dijitIEFixedToolbar {
	position:absolute;
	
	top: expression(eval((document.documentElement||document.body).scrollTop));
}
.dijitEditor {
	display: block;	
}
.dijitEditorDisabled,
.dijitEditorReadOnly {
	color: gray;
}
.dijitTimePickerItemInner {
	text-align:center;
	border:0;
	padding:2px 8px 2px 8px;
}
.dijitTimePickerTick,
.dijitTimePickerMarker {
	border-bottom:1px solid gray;
}
.dijitTimePicker .dijitDownArrowButton {
	border-top: none !important;
}
.dijitTimePickerTick {
	color:#CCC;
}
.dijitTimePickerMarker {
	color:black;
	background-color:#CCC;
}
.dijitTimePickerItemSelected {
	font-weight:bold;
	color:#333;
	background-color:#b7cdee;
}
.dijitTimePickerItemHover {
	background-color:gray;
	color:white;
	cursor:pointer;
}
.dijit_a11y .dijitTimePickerItemSelected .dijitTimePickerItemInner {
	border: solid 4px black;
}
.dijit_a11y .dijitTimePickerItemHover .dijitTimePickerItemInner {
	border: dashed 4px black;
}
.dijitToggleButtonIconChar {
	
	display:none !important;
}
.dijit_a11y .dijitToggleButton .dijitToggleButtonIconChar {
	display:inline !important;
	visibility:hidden;
}
.dj_ie6 .dijitToggleButtonIconChar, .dj_ie6 .tabStripButton .dijitButtonText {
	font-family: "Arial Unicode MS";	
}
.dijit_a11y .dijitToggleButtonChecked .dijitToggleButtonIconChar {
	display: inline !important; 
	visibility:visible !important;
}
.dijitArrowButtonChar {
        display:none !important;
}
.dijit_a11y .dijitArrowButtonChar {
        display:inline !important;
}
.dijit_a11y .dijitDropDownButton .dijitArrowButtonInner,
.dijit_a11y .dijitComboButton .dijitArrowButtonInner {
	display:none !important;
}
.dijitSelect {
	margin: 0.2em;
	border-collapse: collapse;
}
.dj_ie .dijitSelect,
.dj_ie7 .dijitSelect,
.dj_iequirks .dijitSelect {
	vertical-align: middle; 
}
.dj_ie8 .dijitSelect .dijitButtonText {
	vertical-align: top;
}
.dijitToolbar .dijitSelect {
	margin: 0;
}
.dj_webkit .dijitToolbar .dijitSelect {
	padding-left: 0.3em;
}
.dijit_a11y .dijitSelectDisabled .dijitButtonNode {
	border-style: outset!important;
	border-width: medium!important;
	border-color: #999 !important;
	color:#999 !important;
}
.dijitSelect .dijitButtonContents {
	padding: 0;
	background: transparent none;
	white-space: nowrap;
	text-align: left;
}
.dijitSelectFixedWidth .dijitButtonContents {
	width: 100%;
}
.dijitSelectMenu .dijitMenuItemIcon {
	
	display:none;
}
.dj_ie6 .dijitSelectMenu .dijitMenuItemLabel,
.dj_ie7 .dijitSelectMenu .dijitMenuItemLabel {
	
	position: static;
}
.dijitSelectLabel *
{
	vertical-align: baseline;
}
.dijitSelectSelectedOption * {
	font-weight: bold;
}
.dijitSelectMenu {
	border-width: 1px;
}
.dijitSelectMenu .dijitMenuTable {
	margin: 0;
	background-color: transparent;
}
.dijitForceStatic {
	position: static !important;
}
.dijitReadOnly *,
.dijitDisabled *,
.dijitReadOnly,
.dijitDisabled {
	
	cursor: default;
}
.dijitIconSave,
.dijitIconPrint,
.dijitIconCut,
.dijitIconCopy,
.dijitIconClear,
.dijitIconDelete,
.dijitIconUndo,
.dijitIconEdit,
.dijitIconNewTask,
.dijitIconEditTask,
.dijitIconEditProperty,
.dijitIconTask,
.dijitIconFilter,
.dijitIconConfigure,
.dijitIconSearch,
.dijitIconApplication,
.dijitIconBookmark,
.dijitIconChart,
.dijitIconConnector,
.dijitIconDatabase,
.dijitIconDocuments,
.dijitIconMail,
.dijitLeaf,
.dijitIconFile,
.dijitIconFunction,
.dijitIconKey,
.dijitIconPackage,
.dijitIconSample,
.dijitIconTable,
.dijitIconUsers,
.dijitFolderClosed,
.dijitIconFolderClosed,
.dijitFolderOpened,
.dijitIconFolderOpen,
.dijitIconError {
	background-image: url(../../icons/images/commonIconsObjActEnabled.png); 
	width: 16px;
	height: 16px;
}
.dj_ie6 .dijitIconSave,
.dj_ie6 .dijitIconPrint,
.dj_ie6 .dijitIconCut,
.dj_ie6 .dijitIconCopy,
.dj_ie6 .dijitIconClear,
.dj_ie6 .dijitIconDelete,
.dj_ie6 .dijitIconUndo,
.dj_ie6 .dijitIconEdit,
.dj_ie6 .dijitIconNewTask,
.dj_ie6 .dijitIconEditTask,
.dj_ie6 .dijitIconEditProperty,
.dj_ie6 .dijitIconTask,
.dj_ie6 .dijitIconFilter,
.dj_ie6 .dijitIconConfigure,
.dj_ie6 .dijitIconSearch,
.dj_ie6 .dijitIconApplication,
.dj_ie6 .dijitIconBookmark,
.dj_ie6 .dijitIconChart,
.dj_ie6 .dijitIconConnector,
.dj_ie6 .dijitIconDatabase,
.dj_ie6 .dijitIconDocuments,
.dj_ie6 .dijitIconMail,
.dj_ie6 .dijitLeaf,
.dj_ie6 .dijitIconFile,
.dj_ie6 .dijitIconFunction,
.dj_ie6 .dijitIconKey,
.dj_ie6 .dijitIconPackage,
.dj_ie6 .dijitIconSample,
.dj_ie6 .dijitIconTable,
.dj_ie6 .dijitIconUsers,
.dj_ie6 .dijitFolderClosed,
.dj_ie6 .dijitIconFolderClosed,
.dj_ie6 .dijitFolderOpened,
.dj_ie6 .dijitIconFolderOpen,
.dj_ie6 .dijitIconError {
	background-image: url(../../icons/images/commonIconsObjActEnabled8bit.png);
}
.dijitDisabled .dijitIconSave,
.dijitDisabled .dijitIconPrint,
.dijitDisabled .dijitIconCut,
.dijitDisabled .dijitIconCopy,
.dijitDisabled .dijitIconClear,
.dijitDisabled .dijitIconDelete,
.dijitDisabled .dijitIconUndo,
.dijitDisabled .dijitIconEdit,
.dijitDisabled .dijitIconNewTask,
.dijitDisabled .dijitIconEditTask,
.dijitDisabled .dijitIconEditProperty,
.dijitDisabled .dijitIconTask,
.dijitDisabled .dijitIconFilter,
.dijitDisabled .dijitIconConfigure,
.dijitDisabled .dijitIconSearch,
.dijitDisabled .dijitIconApplication,
.dijitDisabled .dijitIconBookmark,
.dijitDisabled .dijitIconChart,
.dijitDisabled .dijitIconConnector,
.dijitDisabled .dijitIconDatabase,
.dijitDisabled .dijitIconDocuments,
.dijitDisabled .dijitIconMail,
.dijitDisabled .dijitLeaf,
.dijitDisabled .dijitIconFile,
.dijitDisabled .dijitIconFunction,
.dijitDisabled .dijitIconKey,
.dijitDisabled .dijitIconPackage,
.dijitDisabled .dijitIconSample,
.dijitDisabled .dijitIconTable,
.dijitDisabled .dijitIconUsers,
.dijitDisabled .dijitFolderClosed,
.dijitDisabled .dijitIconFolderClosed,
.dijitDisabled .dijitFolderOpened,
.dijitDisabled .dijitIconFolderOpen,
.dijitDisabled .dijitIconError {
	background-image: url(../../icons/images/commonIconsObjActDisabled.png); 
}
.dijitIconSave { background-position: 0; }
.dijitIconPrint { background-position: -16px; }
.dijitIconCut { background-position: -32px; }
.dijitIconCopy { background-position: -48px; }
.dijitIconClear { background-position: -64px; }
.dijitIconDelete { background-position: -80px; }
.dijitIconUndo { background-position: -96px; }
.dijitIconEdit { background-position: -112px; }
.dijitIconNewTask { background-position: -128px; }
.dijitIconEditTask { background-position: -144px; }
.dijitIconEditProperty { background-position: -166px; }
.dijitIconTask { background-position: -176px; }
.dijitIconFilter { background-position: -192px; }
.dijitIconConfigure { background-position: -208px; }
.dijitIconSearch { background-position: -224px; }
.dijitIconError { background-position: -496px; } 
.dijitIconApplication { background-position: -240px; }
.dijitIconBookmark { background-position: -256px; }
.dijitIconChart { background-position: -272px; }
.dijitIconConnector { background-position: -288px; }
.dijitIconDatabase { background-position: -304px; }
.dijitIconDocuments { background-position: -320px; }
.dijitIconMail { background-position: -336px; }
.dijitIconFile, .dijitLeaf { background-position: -352px; }
.dijitIconFunction { background-position: -368px; }
.dijitIconKey { background-position: -384px; }
.dijitIconPackage{ background-position: -400px; }
.dijitIconSample { background-position: -416px; }
.dijitIconTable { background-position: -432px; }
.dijitIconUsers { background-position: -448px; }
.dijitIconFolderClosed, .dijitFolderClosed { background-position: -464px; }
.dijitIconFolderOpen, .dijitFolderOpened { background-position: -480px; }
.dijitIconLoading {
	background:url(../../icons/images/loadingAnimation_rtl.gif) no-repeat;
	height: 20px;
	width: 20px;
}
.claro .dijitPopup {
  -webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 5px rgba(0, 0, 0, 0.25);
}
.claro .dijitTooltipDialogPopup {
  
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.claro .dijitComboBoxHighlightMatch {
  background-color: #abd6ff;
}
.claro .dijitFocusedLabel {
  
  outline: 1px dotted #494949;
}
.claro .dojoDndItemBefore, .claro .dojoDndItemAfter {
  border-top: 1px solid #759dc0;
}
.claro .dojoDndItemOver {
  cursor: pointer;
}
.claro table.dojoDndAvatar {
  border: 1px solid #b5bcc7;
  border-collapse: collapse;
  background-color: #ffffff;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25);
}
.claro .dojoDndAvatarHeader td {
  height: 20px;
  padding-left: 21px;
}
.claro.dojoDndMove .dojoDndAvatarHeader, .claro.dojoDndCopy .dojoDndAvatarHeader {
  background-image: url(images/dnd.png);
  background-repeat: no-repeat;
  background-position: 2px -122px;
}
.claro .dojoDndAvatarItem td {
  padding: 5px;
}
.claro.dojoDndMove .dojoDndAvatarHeader {
  background-color: #f58383;
  background-position: 2px -103px;
}
.claro.dojoDndCopy .dojoDndAvatarHeader {
  background-color: #f58383;
  background-position: 2px -68px;
}
.claro.dojoDndMove .dojoDndAvatarCanDrop .dojoDndAvatarHeader {
  background-color: #97e68d;
  background-position: 2px -33px;
}
.claro.dojoDndCopy .dojoDndAvatarCanDrop .dojoDndAvatarHeader {
  background-color: #97e68d;
  background-position: 2px 2px;
}
.claro .dijitTextBox, .claro .dijitInputInner {
  color: #000000;
}
.claro .dijitTextBoxError .dijitValidationContainer {
  background-color: #d46464;
  background-image: url(form/images/error.png);
  background-position: top center;
  border: solid #d46464 0;
  border-left-width: 1px;
  width: 9px;
}
.claro .dijitTextBoxError .dijitValidationIcon {
  width: 0;
  background-color: transparent !important;
  
}
.claro .dijitTextArea, .claro .dijitInputField .dijitPlaceHolder {
  padding: 2px;
}
.claro .dijitTextBox .dijitInputField {
  padding: 1px 2px;
}
.dj_gecko .claro .dijitTextBox .dijitInputInner, .dj_webkit .claro .dijitTextBox .dijitInputInner {
  padding: 1px;
}
.claro .dijitTextBox, .claro .dijitTextBox .dijitButtonNode {
  
  border-color: #b5bcc7;
  -webkit-transition-property: background-color, border;
  -moz-transition-property: background-color, border;
  transition-property: background-color, border;
  -webkit-transition-duration: 0.35s;
  -moz-transition-duration: 0.35s;
  transition-duration: 0.35s;
}
.claro .dijitTextBox {
  background-color: #ffffff;
}
.claro .dijitTextBoxHover, .claro .dijitTextBoxHover .dijitButtonNode {
  border-color: #759dc0;
  -webkit-transition-duration: 0.25s;
  -moz-transition-duration: 0.25s;
  transition-duration: 0.25s;
}
.claro .dijitTextBoxHover {
  background-color: #e5f2fe;
  background-image: url(form/images/textBox_back.png);
  background-repeat: repeat-x;
}
.claro .dijitTextBoxError, .claro .dijitTextBoxError .dijitButtonNode {
  border-color: #d46464;
}
.claro .dijitTextBoxError, .claro .dijitTextBoxError .dijitInputContainer {
  background-color: #ffffff;
}
.claro .dijitTextBoxFocused, .claro .dijitTextBoxFocused .dijitButtonNode {
  border-color: #759dc0;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
.claro .dijitTextBoxFocused {
  background-color: #ffffff;
  background-image: url(form/images/textBox_back.png);
  background-repeat: repeat-x;
}
.claro .dijitTextBoxFocused .dijitInputContainer {
  background: #ffffff;
}
.claro .dijitTextBoxErrorFocused, .claro .dijitTextBoxErrorFocused .dijitButtonNode {
  border-color: #ce5050;
}
.claro .dijitTextBoxDisabled, .claro .dijitTextBoxDisabled .dijitButtonNode {
  border-color: #d3d3d3;
}
.claro .dijitTextBoxDisabled, .claro .dijitTextBoxDisabled .dijitInputContainer {
  background-color: #efefef;
  background-image: none;
}
.claro .dijitTextBoxDisabled, .claro .dijitTextBoxDisabled .dijitInputInner {
  color: #818181;
}
.dj_webkit .claro .dijitTextBoxDisabled input {
  
  color: #757575;
}
.dj_webkit .claro textarea.dijitTextAreaDisabled {
  
  color: #1b1b1b;
}
.claro .dijitComboBox .dijitArrowButtonInner {
  background-image: url(form/images/commonFormArrows.png);
  background-position: -35px 53%;
  background-repeat: no-repeat;
  margin: 0;
  width: 16px;
  border: 1px solid #ffffff;
}
.claro .dijitToolbar .dijitComboBox .dijitArrowButtonInner {
  border: none;
}
.claro .dijitToolbar .dijitComboBox .dijitArrowButtonInner {
  border: none;
}
.claro .dijitTextBox .dijitInputInner, .claro .dijitTextBox .dijitValidationContainer {
  padding: 1px 0;
}
.claro .dijitComboBox .dijitButtonNode {
  background-color: #efefef;
  background-image: url(form/images/formHighlight.png);
  background-repeat: repeat-x;
}
.claro .dijitComboBoxOpenOnClickHover .dijitButtonNode, .claro .dijitComboBox .dijitDownArrowButtonHover {
  background-color: #abd6ff;
}
.claro .dijitComboBoxOpenOnClickHover .dijitArrowButtonInner, .claro .dijitComboBox .dijitDownArrowButtonHover .dijitArrowButtonInner {
  background-position: -70px 53%;
}
.claro .dijitComboBox .dijitHasDropDownOpen {
  background-color: #7dbdfa;
  background-position: 0 -177px;
  padding: 1px;
}
.claro .dijitComboBox .dijitHasDropDownOpen .dijitArrowButtonInner {
  background-position: -70px 53%;
  border: 0 none;
}
.claro div.dijitComboBoxDisabled .dijitArrowButtonInner {
  
  background-position: 0 50%;
  background-color: #efefef;
}
.dj_ff3 .claro .dijitInputField input[type="hidden"] {
  display: none;
  height: 0;
  width: 0;
}
.dj_ie6 .claro .dijitTextBox, .dj_ie6 .claro .dijitComboBox .dijitButtonNode {
  background-image: none;
}
.dj_borderbox .claro .dijitComboBox .dijitHasDropDownOpen .dijitArrowButtonInner {
  width: 18px;
}
.dj_borderbox .claro .dijitComboBoxFocused .dijitHasDropDownOpen .dijitArrowButtonInner {
  width: 16px;
}
.claro .dijitButtonNode {
  
  -webkit-transition-property: background-color;
  -moz-transition-property: background-color;
  transition-property: background-color;
  -webkit-transition-duration: 0.3s;
  -moz-transition-duration: 0.3s;
  transition-duration: 0.3s;
}
.claro .dijitButton .dijitButtonNode,
.claro .dijitDropDownButton .dijitButtonNode,
.claro .dijitComboButton .dijitButtonNode,
.claro .dijitToggleButton .dijitButtonNode {
  
  border: 1px solid #759dc0;
  padding: 2px 4px 4px 4px;
  background-image: url(form/images/button.png);
  background-position: center top;
  background-repeat: repeat-x;
  background-color: #e5f2fe;
  color: #000000;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.15);
  -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.15);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.15);
}
.claro .dijitComboButton .dijitArrowButton {
  border-left-width: 0;
  padding: 4px 2px 4px 2px;
  
}
.claro .dijitArrowButtonInner {
  width: 15px;
  height: 15px;
  margin: 0 auto;
  background-image: url(form/images/buttonArrows.png);
  background-repeat: no-repeat;
  background-position: -51px 53%;
}
.claro .dijitLeftArrowButton .dijitArrowButtonInner {
  background-position: -77px 53%;
}
.claro .dijitRightArrowButton .dijitArrowButtonInner {
  background-position: -26px 53%;
}
.claro .dijitUpArrowButton .dijitArrowButtonInner {
  background-position: 0 53%;
}
.claro .dijitDisabled .dijitArrowButtonInner {
  background-position: -151px 53%;
}
.claro .dijitDisabled .dijitLeftArrowButton .dijitArrowButtonInner {
  background-position: -177px 53%;
}
.claro .dijitDisabled .dijitRightArrowButton .dijitArrowButtonInner {
  background-position: -126px 53%;
}
.claro .dijitDisabled .dijitUpArrowButton .dijitArrowButtonInner {
  background-position: -100px 53%;
}
.claro .dijitButtonText {
  padding: 0 0.3em;
  text-align: center;
}
.claro .dijitButtonHover .dijitButtonNode,
.claro .dijitDropDownButtonHover .dijitButtonNode,
.claro .dijitComboButton .dijitButtonNodeHover,
.claro .dijitComboButton .dijitDownArrowButtonHover,
.claro .dijitToggleButtonHover .dijitButtonNode {
  background-color: #abd6ff;
  color: #000000;
  -webkit-transition-duration: 0.2s;
  -moz-transition-duration: 0.2s;
  transition-duration: 0.2s;
}
.claro .dijitButtonActive .dijitButtonNode,
.claro .dijitDropDownButtonActive .dijitButtonNode,
.claro .dijitComboButtonActive .dijitButtonNode,
.claro .dijitToggleButtonActive .dijitButtonNode,
.claro .dijitStackController .dijitToggleButtonChecked .dijitButtonNode {
  background-color: #abd6ff;
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -moz-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
.claro .dijitButtonDisabled,
.claro .dijitDropDownButtonDisabled,
.claro .dijitComboButtonDisabled,
.claro .dijitToggleButtonDisabled {
  background-image: none;
  outline: none;
}
.claro .dijitButtonDisabled .dijitButtonNode,
.claro .dijitDropDownButtonDisabled .dijitButtonNode,
.claro .dijitComboButtonDisabled .dijitButtonNode,
.claro .dijitToggleButtonDisabled .dijitButtonNode {
  background-position: 0 -149px;
  background-color: #efefef;
  border: solid 1px #d3d3d3;
  color: #818181;
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -moz-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
}
.claro .dijitComboButtonDisabled .dijitArrowButton {
  border-left-width: 0;
}
.claro table.dijitComboButton {
  border-collapse: separate;
  
}
.dj_ie6 .claro .dijitButtonNode {
  background-image: none;
}
.claro .dijitComboButton .dijitStretch {
  -moz-border-radius: 4px 0 0 4px;
  border-radius: 4px 0 0 4px;
}
.claro .dijitComboButton .dijitArrowButton {
  -moz-border-radius: 0 4px 4px 0;
  border-radius: 0 4px 4px 0;
}
.claro .dijitToggleButton .dijitCheckBoxIcon {
  background-image: url(images/checkmarkNoBorder.png);
}
.dj_ie6 .claro .dijitToggleButton .dijitCheckBoxIcon {
  background-image: url(images/checkmarkNoBorder.gif);
}
.claro .dijitCheckBox, .claro .dijitCheckBoxIcon {
  background-image: url(form/images/checkboxRadioButtonStates.png);
  
  background-repeat: no-repeat;
  width: 15px;
  height: 16px;
  margin: 0 2px 0 0;
  padding: 0;
}
.dj_ie6 .claro .dijitCheckBox, .dj_ie6 .claro .dijitCheckBoxIcon {
  background-image: url(form/images/checkboxAndRadioButtons_IE6.png);
  
}
.claro .dijitCheckBox, .claro .dijitToggleButton .dijitCheckBoxIcon {
  
  background-position: -15px;
}
.claro .dijitCheckBoxChecked, .claro .dijitToggleButtonChecked .dijitCheckBoxIcon {
  
  background-position: 0;
}
.claro .dijitCheckBoxDisabled {
  
  background-position: -75px;
}
.claro .dijitCheckBoxCheckedDisabled {
  
  background-position: -60px;
}
.claro .dijitCheckBoxHover {
  
  background-position: -45px;
}
.claro .dijitCheckBoxCheckedHover {
  
  background-position: -30px;
}
.claro .dijitToggleButton .dijitRadio, .claro .dijitToggleButton .dijitRadioIcon {
  background-image: url(form/images/checkboxRadioButtonStates.png);
}
.dj_ie6 .claro .dijitToggleButton .dijitRadio, .dj_ie6 .claro .dijitToggleButton .dijitRadioIcon {
  background-image: url(form/images/checkboxAndRadioButtons_IE6.png);
}
.claro .dijitRadio, .claro .dijitRadioIcon {
  
  background-image: url(form/images/checkboxRadioButtonStates.png);
  
  background-repeat: no-repeat;
  width: 15px;
  height: 15px;
  margin: 0 2px 0 0;
  padding: 0;
}
.dj_ie6 .claro .dijitRadio, .dj_ie6 .claro .dijitRadioIcon {
  
  background-image: url(form/images/checkboxAndRadioButtons_IE6.png);
  
}
.claro .dijitRadio {
  
  background-position: -105px;
}
.claro .dijitToggleButton .dijitRadioIcon {
  
  background-position: -107px;
}
.claro .dijitRadioDisabled {
  
  background-position: -165px;
}
.claro .dijitRadioHover {
  
  background-position: -135px;
}
.claro .dijitRadioChecked {
  background-position: -90px;
}
.claro .dijitToggleButtonChecked .dijitRadioIcon {
  background-position: -92px;
}
.claro .dijitRadioCheckedHover {
  background-position: -120px;
}
.claro .dijitRadioCheckedDisabled {
  
  background-position: -150px;
}
.claro .dijitSelect .dijitButtonText {
  padding: 2px;
}
.claro .dijitSelect {
  border: 1px solid #b5bcc7;
  background-color: #ffffff;
  border-collapse: separate;
}
.dj_ie6 .claro .dijitSelect, .dj_ie6 .claro .dijitSelect .dijitButtonNode {
  background-image: none;
}
.claro .dijitSelect .dijitButtonContents {
  border: 0 solid #b5bcc7;
  border-right-width: 1px;
}
.claro .dijitSelect .dijitArrowButton {
  padding: 0;
  border: 1px solid #ffffff;
  border-top: none;
  background-color: #efefef;
  background-image: url(form/images/formHighlight.png);
  background-repeat: repeat-x;
}
.claro .dijitSelect .dijitArrowButton .dijitArrowButtonInner {
  background-image: url(form/images/commonFormArrows.png);
  background-position: -35px 70%;
  background-repeat: no-repeat;
  width: 16px;
  height: 16px;
}
.claro .dijitSelectHover {
  border: 1px solid #759dc0;
  background-color: #e5f2fe;
  background-image: url(form/images/textBox_back.png);
  background-repeat: repeat-x;
}
.claro .dijitSelectHover .dijitButtonContents {
  border-color: #759dc0;
}
.claro .dijitSelectHover .dijitArrowButton {
  background-color: #abd6ff;
}
.claro .dijitSelectHover .dijitArrowButton .dijitArrowButtonInner {
  background-position: -70px 70%;
}
.claro .dijitSelectFocused {
  border: 1px solid #759dc0;
}
.claro .dijitSelectFocused .dijitButtonContents {
  border-color: #759dc0;
}
.claro .dijitSelectFocused .dijitArrowButton {
  background-color: #7dbefa;
  background-position: 0 -177px;
  border: none;
  padding: 0 1px;
}
.claro .dijitSelectFocused .dijitArrowButton .dijitArrowButtonInner {
  background-position: -70px 70%;
  margin-bottom: 1px;
}
.claro .dijitSelectDisabled {
  border: 1px solid #d3d3d3;
  background-color: #efefef;
  background-image: none;
  color: #818181;
}
.claro .dijitSelectDisabled .dijitArrowButton {
  background-color: #efefef;
}
.claro .dijitSelectDisabled .dijitArrowButton .dijitArrowButtonInner {
  background-position: 0 70%;
}
.claro .dijitSelectMenu td.dijitMenuItemIconCell, .claro .dijitSelectMenu td.dijitMenuArrowCell {
  
  display: none;
}
.claro .dijitSelectMenu td.dijitMenuItemLabel {
  
  padding: 2px;
}
.claro .dijitSelectMenu .dijitMenuSeparatorTop {
  border-bottom: 1px solid #759dc0;
}
.claro .dijitTabPaneWrapper {
  background: #ffffff;
}
.claro .dijitTabPaneWrapper,
.claro .dijitTabContainerTop-tabs,
.claro .dijitTabContainerBottom-tabs,
.claro .dijitTabContainerLeft-tabs,
.claro .dijitTabContainerRight-tabs {
  
  border-color: #b5bcc7;
}
.claro .dijitTabCloseButton {
  background: url(layout/images/tabClose.png) no-repeat;
  width: 14px;
  height: 14px;
  margin-left: 5px;
  margin-right: -5px;
}
.claro .dijitTabCloseButtonHover {
  background-position: -14px;
}
.claro .dijitTabCloseButtonActive {
  background-position: -28px;
}
.claro .dijitTabSpacer {
  
  display: none;
}
.claro .dijitTabInnerDiv {
  background-color: #efefef;
  -webkit-transition-property: background-color, border;
  -moz-transition-property: background-color, border;
  transition-property: background-color, border;
  -webkit-transition-duration: 0.35s;
  -moz-transition-duration: 0.35s;
  transition-duration: 0.35s;
  color: #494949;
}
.claro .dijitTabHover .dijitTabInnerDiv {
  background-color: #abd6ff;
  -webkit-transition-duration: 0.25s;
  -moz-transition-duration: 0.25s;
  transition-duration: 0.25s;
  color: #000000;
}
.claro .dijitTabActive .dijitTabInnerDiv {
  background-color: #7dbdfa;
  color: #000000;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
.claro .dijitTabChecked .dijitTabInnerDiv {
  background-color: #cfe5fa;
  color: #000000;
}
.claro .dijitTabContent {
  border: 1px solid #b5bcc7;
}
.claro .dijitTabHover .dijitTabContent {
  border-color: #759dc0;
}
.claro .dijitTabActive .dijitTabContent {
  border-color: #759dc0;
}
.claro .dijitTabChecked .dijitTabContent {
  color: #000000;
  border-color: #b5bcc7;
}
.claro .tabStripButton .dijitTabInnerDiv {
  background-color: transparent;
}
.claro .tabStripButton .dijitTabContent {
  border: none;
}
.claro .dijitTabContainerTop-tabs .dijitTab {
  top: 1px;
  
  margin-right: 1px;
  padding-top: 3px;
}
.dj_ie7 .claro .dijitTabContainerTop-tabs .dijitTab {
  top: 3px;
}
.claro .dijitTabContainerTop-tabs .dijitTabContent {
  padding: 3px 6px;
  border-bottom-width: 0;
  background-image: url(layout/images/tabTop.png);
  background-position: 0 0;
  background-repeat: repeat-x;
  min-width: 60px;
  text-align: center;
}
.claro .dijitTabContainerTop-tabs .dijitTabChecked .dijitTabContent {
  padding-bottom: 4px;
  padding-top: 6px;
}
.claro .dijitTabContainerTop-tabs .dijitTabInnerDiv {
  background-image: url(layout/images/tabTop.png);
  background-position: 0 -248px;
  background-position: bottom;
  background-repeat: repeat-x;
  -webkit-box-shadow: 0 -1px 1px rgba(0, 0, 0, 0.04);
  -moz-box-shadow: 0 -1px 1px rgba(0, 0, 0, 0.04);
  box-shadow: 0 -1px 1px rgba(0, 0, 0, 0.04);
}
.claro .dijitTabContainerTop-tabs .dijitTabChecked .dijitTabInnerDiv {
  background-image: none;
  -webkit-box-shadow: 0 -1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: 0 -1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: 0 -1px 2px rgba(0, 0, 0, 0.05);
}
.claro .dijitTabContainerTop-tabs .dijitTabChecked .dijitTabContent {
  background-position: 0 -102px;
  background-repeat: repeat-x;
}
.claro .dijitTabContainerBottom-tabs .dijitTab {
  top: -1px;
  
  margin-right: 1px;
}
.claro .dijitTabContainerBottom-tabs .dijitTabContent {
  padding: 3px 6px;
  border-top-width: 0;
  background-image: url(layout/images/tabBottom.png);
  background-position: 0 -249px;
  background-repeat: repeat-x;
  background-position: bottom;
  min-width: 60px;
  text-align: center;
}
.claro .dijitTabContainerBottom-tabs .dijitTab {
  padding-bottom: 3px;
}
.claro .dijitTabContainerBottom-tabs .dijitTabInnerDiv {
  background-image: url(layout/images/tabBottom.png);
  background-position: top;
  background-repeat: repeat-x;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
  -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
}
.claro .dijitTabContainerBottom-tabs .dijitTabChecked .dijitTabContent {
  padding-bottom: 7px;
  padding-top: 4px;
  background-position: 0 -119px;
}
.claro .dijitTabContainerBottom-tabs .dijitTabChecked {
  padding-bottom: 0;
}
.claro .dijitTabContainerBottom-tabs .dijitTabChecked .dijitTabInnerDiv {
  background-image: none;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}
.claro .dijitTabContainerLeft-tabs .dijitTab {
  border-right-width: 0;
  left: 1px;
  
  margin-bottom: 1px;
}
.claro .dijitTabContainerLeft-tabs .dijitTabInnerDiv {
  background-image: url(layout/images/tabLeft.png);
  background-position: -347px -340px;
  background-repeat: repeat-y;
}
.claro .dijitTabContainerLeft-tabs .dijitTabContent {
  padding: 3px 8px 4px 4px;
  background-image: url(layout/images/tabLeft.png);
  background-repeat: repeat-y;
  background-position: 0 0;
}
.claro .dijitTabContainerLeft-tabs .dijitTabChecked .dijitTabContent {
  padding-right: 9px;
  border-right: none;
  background-image: none;
}
.claro .dijitTabContainerLeft-tabs .dijitTabChecked .dijitTabInnerDiv {
  background-position: 0 -179px;
  background-repeat: repeat-y;
  -webkit-box-shadow: -1px 0 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: -1px 0 2px rgba(0, 0, 0, 0.05);
  box-shadow: -1px 0 2px rgba(0, 0, 0, 0.05);
}
.claro .dijitTabContainerRight-tabs .dijitTab {
  border-left-width: 0;
  left: -1px;
  
  margin-bottom: 1px;
}
.claro .dijitTabContainerRight-tabs .dijitTabInnerDiv {
  background-image: url(layout/images/tabRight.png);
  background-repeat: repeat-y;
  background-position: -1px -347px;
}
.claro .dijitTabContainerRight-tabs .dijitTabContent {
  padding: 3px 8px 4px 4px;
  background-image: url(layout/images/tabRight.png);
  background-position: right top;
  background-repeat: repeat-y;
}
.claro .dijitTabContainerRight-tabs .dijitTabChecked .dijitTabContent {
  padding-left: 5px;
  border-left: none;
  background-image: none;
}
.claro .dijitTabContainerRight-tabs .dijitTabChecked .dijitTabInnerDiv {
  background-position: -348px -179px;
  -webkit-box-shadow: 1px 0 2px rgba(0, 0, 0, 0.07);
  -moz-box-shadow: 1px 0 2px rgba(0, 0, 0, 0.07);
  box-shadow: 1px 0 2px rgba(0, 0, 0, 0.07);
}
.claro .dijitTabContainerTop-tabs .dijitTabInnerDiv, .claro .dijitTabContainerTop-tabs .dijitTabContent {
  -moz-border-radius: 2px 2px 0 0;
  border-radius: 2px 2px 0 0;
}
.claro .dijitTabContainerBottom-tabs .dijitTabInnerDiv, .claro .dijitTabContainerBottom-tabs .dijitTabContent {
  -moz-border-radius: 0 0 2px 2px;
  border-radius: 0 0 2px 2px;
}
.claro .dijitTabContainerLeft-tabs .dijitTabInnerDiv, .claro .dijitTabContainerLeft-tabs .dijitTabContent {
  -moz-border-radius: 2px 0 0 2px;
  border-radius: 2px 0 0 2px;
}
.claro .dijitTabContainerRight-tabs .dijitTabInnerDiv, .claro .dijitTabContainerRight-tabs .dijitTabContent {
  -moz-border-radius: 0 2px 2px 0;
  border-radius: 0 2px 2px 0;
}
.claro .tabStripButton {
  background-color: #e5f2fe;
  border: 1px solid #b5bcc7;
}
.claro .dijitTabListContainer-top .tabStripButton {
  padding: 4px 3px;
  margin-top: 7px;
  background-image: url(layout/images/tabTop.png);
  background-position: 0 0;
}
.claro .dijitTabListContainer-bottom .tabStripButton {
  padding: 5px 3px;
  margin-bottom: 4px;
  background-image: url(layout/images/tabTop.png);
  background-position: 0 -248px;
  background-position: bottom;
}
.claro .tabStripButtonHover {
  background-color: #abd6ff;
}
.claro .tabStripButtonActive {
  background-color: #7dbdfa;
}
.claro .dijitTabStripIcon {
  height: 15px;
  width: 15px;
  margin: 0 auto;
  background: url(form/images/buttonArrows.png) no-repeat -75px 50%;
  background-color: transparent;
}
.claro .dijitTabStripSlideRightIcon {
  background-position: -24px 50%;
}
.claro .dijitTabStripMenuIcon {
  background-position: -51px 50%;
}
.claro .dijitTabListContainer-top .tabStripButtonDisabled, .claro .dijitTabListContainer-bottom .tabStripButtonDisabled {
  background-color: #d3d3d3;
  border: 1px solid #b5bcc7;
  
}
.claro .tabStripButtonDisabled .dijitTabStripSlideLeftIcon {
  background-position: -175px 50%;
}
.claro .tabStripButtonDisabled .dijitTabStripSlideRightIcon {
  background-position: -124px 50%;
}
.claro .tabStripButtonDisabled .dijitTabStripMenuIcon {
  background-position: -151px 50%;
}
.claro .dijitTabContainerNested .dijitTabListWrapper {
  height: auto;
}
.claro .dijitTabContainerNested .dijitTabContainerTop-tabs {
  border-bottom: solid 1px #b5bcc7;
  padding: 1px 2px 4px;
  margin-top: -2px;
}
.claro .dijitTabContainerTabListNested .dijitTabContent {
  background: rgba(255, 255, 255, 0) none repeat scroll 0 0;
  border: none;
  padding: 4px;
  border-color: rgba(118, 157, 192, 0);
  -webkit-transition-property: background-color, border-color;
  -moz-transition-property: background-color, border-color;
  transition-property: background-color, border-color;
  -webkit-transition-duration: 0.3s;
  -moz-transition-duration: 0.3s;
  transition-duration: 0.3s;
  -moz-border-radius: 2px;
  border-radius: 2px;
}
.claro .dijitTabContainerTabListNested .dijitTab .dijitTabInnerDiv {
  
  background: none;
  border: none;
  top: 0;
  
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.claro .dijitTabContainerTabListNested .dijitTabHover .dijitTabContent {
  background-color: #e5f2fe;
  border: solid 1px #cfe5fa;
  padding: 3px;
  -webkit-transition-duration: 0.2s;
  -moz-transition-duration: 0.2s;
  transition-duration: 0.2s;
}
.claro .dijitTabContainerTabListNested .dijitTabHover .tabLabel {
  text-decoration: none;
}
.claro .dijitTabContainerTabListNested .dijitTabActive .dijitTabContent {
  border: solid 1px #759dc0;
  padding: 3px;
  background: #abd6ff url(layout/images/tabNested.png) repeat-x;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
.claro .dijitTabContainerTabListNested .dijitTabChecked .dijitTabContent {
  padding: 3px;
  border: solid 1px #759dc0;
  background-position: 0 105px;
  background-color: #cfe5fa;
}
.claro .dijitTabContainerTabListNested .dijitTabChecked .tabLabel {
  text-decoration: none;
  background-image: none;
}
.claro .dijitTabPaneWrapperNested {
  border: none;
  
}
.dj_ie6 .claro .dijitTabContent,
.dj_ie6 .claro .dijitTabInnerDiv,
.dj_ie6 .dijitTabListContainer-top .tabStripButton,
.dj_ie6 .dijitTabListContainer-bottom .tabStripButton {
  background-image: none;
}
.claro .dijitDialog {
  border: 1px solid #759dc0;
  -webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 5px rgba(0, 0, 0, 0.25);
}
.claro .dijitDialogPaneContent {
  background: #ffffff repeat-x top left;
  border-top: 1px solid #759dc0;
  padding: 10px 8px;
  position: relative;
}
.claro .dijitDialogPaneContentArea {
  
  margin: -10px -8px;
  padding: 10px 8px;
}
.claro .dijitDialogPaneActionBar {
  
  background-color: #efefef;
  padding: 3px 5px 2px 7px;
  text-align: right;
  border-top: 1px solid #d3d3d3;
  margin: 10px -8px -10px;
}
.claro .dijitDialogPaneActionBar .dijitButton {
  float: none;
}
.claro .dijitDialogTitleBar {
  
  border: 1px solid #ffffff;
  border-top: none;
  background-color: #abd6ff;
  background-image: url(images/titlebar.png);
  background-repeat: repeat-x;
  padding: 5px 7px 4px 7px;
}
.claro .dijitDialogTitle {
  
  padding: 0 1px;
  font-size: 1.091em;
  color: #000000;
}
.claro .dijitDialogCloseIcon {
  
  background: url(images/dialogCloseIcon.png);
  background-repeat: no-repeat;
  position: absolute;
  right: 5px;
  height: 15px;
  width: 21px;
}
.dj_ie6 .claro .dijitDialogCloseIcon {
  background-image: url(images/dialogCloseIcon8bit.png);
}
.claro .dijitDialogCloseIconHover {
  background-position: -21px;
}
.claro .dijitDialogCloseIconActive {
  background-position: -42px;
}
.claro .dijitTooltip, .claro .dijitTooltipDialog {
  
  background: transparent;
  
}
.dijitTooltipBelow {
  
  padding-top: 13px;
  padding-left: 3px;
  padding-right: 3px;
}
.dijitTooltipAbove {
  
  padding-bottom: 13px;
  padding-left: 3px;
  padding-right: 3px;
}
.claro .dijitTooltipContainer {
  
  background-color: #ffffff;
  background-image: url(images/tooltipGradient.png);
  background-repeat: repeat-x;
  background-position: bottom;
  border: 1px solid #759dc0;
  padding: 6px 8px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25);
  font-size: 1em;
  color: #000000;
}
.dj_ie6 .claro .dijitTooltipContainer {
  background-image: none;
}
.claro .dijitTooltipConnector {
  
  border: 0;
  z-index: 2;
  background-image: url(images/tooltip.png);
  background-repeat: no-repeat;
  width: 16px;
  height: 14px;
}
.dj_ie6 .claro .dijitTooltipConnector {
  background-image: url(images/tooltip8bit.png);
}
.claro .dijitTooltipABRight .dijitTooltipConnector {
  
  left: auto !important;
  right: 3px;
}
.claro .dijitTooltipBelow .dijitTooltipConnector {
  
  top: 0;
  left: 3px;
  background-position: -31px 0;
  width: 16px;
  height: 14px;
}
.claro .dijitTooltipAbove .dijitTooltipConnector {
  
  bottom: 0;
  left: 3px;
  background-position: -15px 0;
  width: 16px;
  height: 14px;
}
.dj_ie7 .claro .dijitTooltipAbove .dijitTooltipConnector, .dj_ie6 .claro .dijitTooltipAbove .dijitTooltipConnector {
  bottom: -1px;
}
.claro .dijitTooltipLeft {
  padding-right: 14px;
}
.claro .dijitTooltipLeft .dijitTooltipConnector {
  
  right: 0;
  background-position: 0 0;
  width: 16px;
  height: 14px;
}
.claro .dijitTooltipRight {
  padding-left: 14px;
}
.claro .dijitTooltipRight .dijitTooltipConnector {
  
  left: 0;
  background-position: -48px 0;
  width: 16px;
  height: 14px;
}
.claro .dijitDialogUnderlay {
  background: #ffffff;
}
.claro .dijitAccordionContainer {
  border: none;
}
.claro .dijitAccordionInnerContainer {
  background-color: #efefef;
  
  border: solid 1px #b5bcc7;
  margin-bottom: 1px;
  -webkit-transition-property: background-color, border;
  -moz-transition-property: background-color, border;
  transition-property: background-color, border;
  -webkit-transition-duration: 0.3s;
  -moz-transition-duration: 0.3s;
  transition-duration: 0.3s;
  -webkit-transition-timing-function: linear;
  -moz-transition-timing-function: linear;
  transition-timing-function: linear;
}
.claro .dijitAccordionTitle {
  background-color: transparent;
  
  background-image: url(layout/images/accordion.png);
  background-position: 0 0;
  background-repeat: repeat-x;
  padding: 5px 7px 2px 7px;
  min-height: 17px;
  color: #494949;
}
.dj_ie6 .claro .dijitAccordionTitle {
  background-image: none;
}
.claro .dijitAccordionContainer .dijitAccordionChildWrapper {
  
  background-color: #ffffff;
  border: 1px solid #759dc0;
  margin: 0 2px 2px;
}
.claro .dijitAccordionContainer .dijitAccordionContainer-child {
  
  padding: 9px;
}
.claro .dijitAccordionInnerContainerActive {
  border: 1px solid #759dc0;
  background-color: #7dbdfa;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
.claro .dijitAccordionInnerContainerActive .dijitAccordionTitle {
  background-position: 0 -136px;
  color: #000000;
}
.claro .dijitAccordionInnerContainerSelected {
  border-color: #759dc0;
  background-color: #cfe5fa;
}
.claro .dijitAccordionInnerContainerSelected .dijitAccordionTitle {
  color: #000000;
  background-position: 0 0;
  
}
.claro .dijitAccordionInnerContainerHover .dijitAccordionTitle {
  
  color: #000000;
}
.claro .dijitAccordionInnerContainerHover, .claro .dijitAccordionInnerContainerSelectedActive {
  
  border: 1px solid #759dc0;
  background-color: #abd6ff;
  -webkit-transition-duration: 0.2s;
  -moz-transition-duration: 0.2s;
  transition-duration: 0.2s;
}
.claro .dijitAccordionInnerContainerSelectedHover .dijitAccordionChildWrapper, .claro .dijitAccordionInnerContainerSelectedActive .dijitAccordionChildWrapper {
  background-color: #ffffff;
  border: 1px solid #759dc0 !important;
  -webkit-box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.25);
  -moz-box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.25);
  box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.25);
}
.claro .dijitContentPane {
  padding: 8px;
}
.claro .dijitTabContainerTop-dijitContentPane,
.claro .dijitTabContainerLeft-dijitContentPane,
.claro .dijitTabContainerBottom-dijitContentPane,
.claro .dijitTabContainerRight-dijitContentPane,
.claro .dijitAccordionContainer-dijitContentPane {
  background-color: #ffffff;
  padding: 8px;
}
.claro .dijitSplitContainer-dijitContentPane, .claro .dijitBorderContainer-dijitContentPane {
  background-color: #ffffff;
  padding: 8px;
}
.claro .dijitCalendar {
  border: solid 1px #b5bcc7;
  background-color: #cfe5fa;
  background-image: url(images/calendarContainerImages.png);
  background-position: 0 -448px;
  background-repeat: repeat-x;
  text-align: center;
  padding: 6px 5px 3px 5px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  border-collapse: separate;
}
.dj_ie6 .claro .dijitCalendar {
  background-image: none;
}
.claro .dijitCalendar img {
  border: none;
}
.claro .dijitCalendarHover, .claro .dijitCalendar:hover, .claro .dijitCalendarActive {
  
  background-color: #abd6ff;
  border: solid 1px #759dc0;
}
.claro .dijitCalendarMonthContainer th {
  text-align: center;
  padding-bottom: 4px;
  vertical-align: middle;
}
.claro .dijitCalendarMonthLabel {
  color: #000000;
  font-size: 1.091em;
  padding: 0 4px;
}
.claro .dijitCalendarIncrementControl {
  width: 18px;
  height: 16px;
  background-image: url(images/calendarArrows.png);
  background-repeat: no-repeat;
}
.dj_ie6 .claro .dijitCalendarIncrementControl {
  background-image: url(images/calendarArrows8bit.png);
}
.claro .dijitCalendarIncrease {
  background-position: -18px 0;
}
.claro .dijitCalendarArrowHover .dijitCalendarDecrease, .claro .dijitCalendarArrow:hover .dijitCalendarDecrease {
  background-position: -36px 0;
}
.claro .dijitCalendarArrowHover .dijitCalendarIncrease, .claro .dijitCalendarArrow:hover .dijitCalendarIncrease {
  background-position: -55px 0;
}
.claro .dijitCalendarArrowActive .dijitCalendarDecrease, .claro .dijitCalendarArrow:active .dijitCalendarDecrease {
  background-position: -72px 0;
}
.claro .dijitCalendarArrowActive .dijitCalendarIncrease, .claro .dijitCalendarArrow:active .dijitCalendarIncrease {
  background-position: -91px 0;
}
.claro .dijitA11ySideArrow {
  
  display: none;
}
.claro .dijitCalendarDayLabelTemplate {
  padding-bottom: 0;
  text-align: center;
  border-bottom: 1px solid #b5bcc7;
  padding: 0 3px 2px;
}
.claro .dijitCalendarDayLabel {
  padding: 0 4px 0 4px;
  font-weight: bold;
  font-size: 0.909em;
  text-align: center;
  color: #000000;
}
.claro .dijitCalendarDateTemplate {
  text-align: center;
  background-color: #ffffff;
  background-image: url(images/calendarContainerImages.png);
  background-position: 0 0;
  background-repeat: repeat-x;
  border-bottom: 1px solid #d3d3d3;
  padding-top: 0;
  font-size: 0.909em;
  font-family: Arial;
  font-weight: bold;
  letter-spacing: .05em;
  text-align: center;
  color: #000000;
}
.dj_ie6 .claro .dijitCalendarDateTemplate {
  background-image: none;
}
.claro .dijitCalendarPreviousMonth, .claro .dijitCalendarNextMonth {
  background-color: #e5f2fe;
  background-image: none;
  border-bottom: solid 1px #d3d3d3;
  
}
.claro .dijitCalendarDateTemplate .dijitCalendarDateLabel {
  text-decoration: none;
  display: block;
  padding: 3px 5px 3px 4px;
  border: solid 1px #ffffff;
  
  background-color: rgba(171, 212, 251, 0);
  
  -webkit-transition-property: background-color, border;
  -moz-transition-property: background-color, border;
  transition-property: background-color, border;
  -webkit-transition-duration: 0.35s;
  -moz-transition-duration: 0.35s;
  transition-duration: 0.35s;
}
.claro .dijitCalendarPreviousMonth .dijitCalendarDateLabel, .claro .dijitCalendarNextMonth .dijitCalendarDateLabel {
  color: #759dc0;
  border-color: #e5f2fe;
  
}
.claro .dijitCalendarYearContainer {
  vertical-align: middle;
}
.claro .dijitCalendarYearControl {
  padding: 1px 2px 2px 2px;
}
.claro .dijitCalendarYearLabel {
  padding: 2px 0 0 0;
  margin: 0;
  font-size: 1.17em;
}
.claro .dijitCalendarYearLabel span {
  
  vertical-align: middle;
}
.claro .dijitCalendarSelectedYear {
  padding: 0 3px;
}
.claro .dijitCalendarNextYear, .claro .dijitCalendarPreviousYear {
  padding: 1px 6px 1px 6px;
  font-size: 0.909em;
}
.claro .dijitCalendarSelectedYear {
  font-size: 1.091em;
  color: #000000;
}
.claro .dijitCalendarHoveredDate .dijitCalendarDateLabel, .claro .dijitCalendarEnabledDate:hover .dijitCalendarDateLabel {
  background-color: #abd6ff;
  border: solid 1px #759dc0;
  color: #000000;
  -webkit-transition-duration: 0.2s;
  -moz-transition-duration: 0.2s;
  transition-duration: 0.2s;
}
.claro .dijitCalendarNextYearHover,
.claro .dijitCalendarNextYear:hover,
.claro .dijitCalendarPreviousYearHover,
.claro .dijitCalendarPreviousYear:hover {
  color: #000000;
  border: solid 1px #ffffff;
  padding: 0 5px 0 5px;
  
  background-color: #e5f2fe;
}
.claro .dijitCalendarNextYearActive, .claro .dijitCalendarNextYear:active.claro .dijitCalendarPreviousYearActive, .claro .dijitCalendarPreviousYear:active {
  border: solid 1px #759dc0;
  padding: 0 5px 0 5px;
  
  background-color: #7dbdfa;
}
.claro .dijitCalendarActiveDate .dijitCalendarDateLabel, .claro .dijitCalendarEnabledDate:active .dijitCalendarDateLabel {
  background-image: url(images/calendarContainerImages.png);
  background-position: 0 -300px;
  background-color: #7dbdfa;
  border: solid 1px #ffffff;
  -webkit-transition-duration: 0.1s;
  -moz-transition-duration: 0.1s;
  transition-duration: 0.1s;
}
.dj_ie6 .claro .dijitCalendarActiveDate .dijitCalendarDateLabel {
  background-image: none;
}
.claro .dijitCalendarSelectedDate .dijitCalendarDateLabel {
  color: #000000;
  background-color: #abd6ff;
  border-color: #759dc0;
}
.claro .dijitCalendarDisabledDate .dijitCalendarDateLabel {
  color: #818181;
  text-decoration: line-through;
}
.claro .dijitCalendar .dijitDropDownButton {
  margin: 0;
}
.claro .dijitCalendar .dijitButtonText {
  padding: 1px 0 3px;
  margin-right: -4px;
}
.claro .dijitCalendar .dijitDropDownButton .dijitButtonNode {
  background-color: transparent;
  background-image: none;
  padding: 0 3px 0 2px;
  border: solid 1px #b5bcc7;
  -webkit-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  -moz-box-shadow: 0 0 0 rgba(0, 0, 0, 0);
  box-shadow: 0 0 0 rgba(0, 0, 0, 0);
}
.claro .dijitCalendar .dijitDropDownButtonHover .dijitButtonNode, .claro .dijitCalendar .dijitDropDownButton:hover .dijitButtonNode {
  background-color: #e5f2fe;
  border: solid 1px #ffffff;
}
.claro .dijitCalendarMonthMenu {
  border-color: #759dc0;
  background-color: #ffffff;
  text-align: center;
  background-image: none;
}
.claro .dijitCalendarMonthMenu .dijitCalendarMonthLabel {
  border-top: solid 1px #ffffff;
  
  border-bottom: solid 1px #ffffff;
  padding: 2px 0;
}
.claro .dijitCalendarMonthMenu .dijitCalendarMonthLabelHover, .claro .dijitCalendarMonthMenu .dijitCalendarMonthLabel:hover {
  background-color: #abd6ff;
  border-color: #759dc0;
  border-width: 1px 0;
  background-image: url(images/commonHighlight.png);
  background-repeat: repeat-x;
}
.claro .dijitMenuBar {
  border: 1px solid #b5bcc7;
  margin: 0;
  padding: 0;
  background-color: #efefef;
  background-image: url(images/commonHighlight.png);
  background-position: 0 0;
  background-repeat: repeat-x;
}
.dj_ie6 .claro .dijitMenuBar {
  background-image: none;
}
.claro .dijitMenu {
  background-repeat: repeat-y;
  background-color: #ffffff;
  border: 1px solid #759dc0;
  
  margin: -1px 0;
}
.dj_ie6 .claro .dijitMenu {
  margin: 0;
  
}
.claro .dijitMenuBar .dijitMenuItem {
  padding: 6px 10px 7px;
  background-position: 0 100px;
  margin: -1px;
}
.claro .dijitMenuItem {
  background-image: url(images/menuHighlight.png);
  background-position: 0 -40px;
  background-repeat: repeat-x;
  color: #000000;
}
.claro .dijitMenuTable {
  border-collapse: separate;
  border-spacing: 0 0;
  padding: 0;
}
.claro .dijitMenuItem td {
  padding: 1px;
}
.claro .dijitMenuPassive .dijitMenuItemHover, .claro .dijitMenuPassive .dijitMenuItemSelected {
  background-color: #abd6ff;
  border: solid 1px #759dc0;
  background-position: 0 0;
  color: #000000;
  padding: 5px 9px 6px;
}
.claro .dijitMenuPassive .dijitMenuItemActive {
  background-position: 0 -177px;
}
.dj_ie6 .claro .dijitMenuItem, .dj_ie6 .claro .dijitMenuPassive .dijitMenuItem {
  background-image: none;
}
.claro .dijitMenuActive .dijitMenuItemHover, .claro .dijitMenuActive .dijitMenuItemSelected {
  border: solid 1px #759dc0;
  padding: 5px 9px 6px;
  background-color: #abd6ff;
  background-position: 0 0;
  color: #000000;
}
.dj_ie .claro .dijitMenuActive .dijitMenuItemHover,
.dj_ie .claro .dijitMenuActive .dijitMenuItemSelected,
.dj_ie .claro .dijitMenuPassive .dijitMenuItemHover,
.dj_ie .claro .dijitMenuPassive .dijitMenuItemSelected {
  padding-top: 6px;
  padding-bottom: 5px;
  margin-top: -3px;
}
.claro .dijitMenuActive .dijitMenuItemActive {
  background-color: #7dbdfa;
  background-position: 0 -177px;
}
.claro .dijitMenuItemActive {
  background-position: 0 -177px;
}
.claro td.dijitMenuItemIconCell {
  padding: 2px;
  margin: 0 0 0 4px;
}
.claro td.dijitMenuItemLabel {
  padding-top: 5px;
  padding-bottom: 5px;
}
.claro .dijitMenuExpand {
  width: 7px;
  height: 7px;
  background-image: url(images/spriteArrows.png);
  background-position: -14px 0;
  margin-right: 3px;
}
.claro .dijitMenuItemDisabled .dijitMenuItemIconCell {
  opacity: 1;
}
.claro .dijitMenuSeparatorTop {
  height: auto;
  margin-top: 1px;
  
  border-bottom: 1px solid #b5bcc7;
}
.claro .dijitMenuSeparatorBottom {
  height: auto;
  margin-bottom: 1px;
}
.claro .dijitCheckedMenuItemIconChar {
  display: none;
}
.claro .dijitCheckedMenuItemIcon {
  background-image: url(form/images/checkboxRadioButtonStates.png);
  background-repeat: no-repeat;
  background-position: -15px 50%;
  width: 15px;
  height: 16px;
}
.dj_ie6 .claro .dijitCheckedMenuItemIcon {
  background-image: url(form/images/checkboxAndRadioButtons_IE6.png);
}
.claro .dijitCheckedMenuItemChecked .dijitCheckedMenuItemIcon {
  background-position: 0 50%;
}
.claro .dijitComboBoxMenu {
  margin-left: 0;
  background-image: none;
}
.claro .dijitComboBoxMenu .dijitMenuItem {
  padding: 2px;
  border-width: 1px 0 1px 0;
  border-style: solid;
  border-color: #ffffff;
}
.claro .dijitComboBoxMenu .dijitMenuItemSelected {
  color: #000000;
  border-color: #759dc0;
  background-color: #abd6ff;
}
.claro .dijitComboBoxMenu .dijitMenuItemHover {
  color: #000000;
  border-color: #769dc0;
  background-color: #abd6ff;
  background-position: 0 0;
}
.claro .dijitComboBoxMenuActive .dijitMenuItemSelected {
  background-position: 0 -177px;
  background-color: #7dbdfa;
  
}
.claro .dijitMenuPreviousButton, .claro .dijitMenuNextButton {
  font-style: italic;
}
.claro .dijitSliderBar {
  border-style: solid;
  outline: 1px;
}
.claro .dijitSliderFocused .dijitSliderBar {
  border-color: #759dc0;
}
.claro .dijitSliderHover .dijitSliderBar {
  border-color: #759dc0;
}
.claro .dijitSliderDisabled .dijitSliderBar {
  background-image: none;
  border-color: #d3d3d3;
}
.claro .dijitRuleLabel {
  color: #000000;
}
.claro .dijitRuleLabelsContainerH {
  padding: 2px 0;
}
.claro .dijitSlider .dijitSliderProgressBarH, .claro .dijitSlider .dijitSliderLeftBumper {
  background-image: url(form/images/sliderHorizontal.png);
  background-repeat: repeat-x;
  background-position: 0 -20px;
  border-color: #b5bcc7;
  background-color: #cfe5fa;
}
.claro .dijitSlider .dijitSliderRemainingBarH, .claro .dijitSlider .dijitSliderRightBumper {
  background-image: url(form/images/sliderHorizontal.png);
  background-repeat: repeat-x;
  background-position: 0 -11px;
  border-color: #b5bcc7;
  background-color: #ffffff;
}
.claro .dijitSliderRightBumper {
  border-right: solid 1px #b5bcc7;
}
.claro .dijitSliderLeftBumper {
  border-left: solid 1px #b5bcc7;
}
.claro .dijitSliderHover .dijitSliderProgressBarH, .claro .dijitSliderHover .dijitSliderLeftBumper {
  background-position: 0 -20px;
  background-color: #abd6ff;
  border-color: #759dc0;
}
.claro .dijitSliderHover .dijitSliderRemainingBarH, .claro .dijitSliderHover .dijitSliderRightBumper {
  background-position: 0 0;
  background-color: #ffffff;
  border-color: #759dc0;
}
.claro .dijitSliderFocused .dijitSliderProgressBarH, .claro .dijitSliderFocused .dijitSliderLeftBumper {
  background-position: 0 -30px;
  background-color: #abd6ff;
  border-color: #759dc0;
}
.claro .dijitSliderFocused .dijitSliderRemainingBarH, .claro .dijitSliderFocused .dijitSliderRightBumper {
  background-position: 0 -9px;
  background-color: #ffffff;
  border-color: #759dc0;
}
.claro .dijitSliderDisabled .dijitSliderProgressBarH, .claro .dijitSliderDisabled .dijitSliderLeftBumper {
  background-color: #d3d3d3;
  
  background-image: none;
}
.claro .dijitSliderDisabled .dijitSliderRemainingBarH, .claro .dijitSliderDisabled .dijitSliderRightBumper {
  background-color: #efefef;
}
.claro .dijitRuleLabelsContainerV {
  padding: 0 2px;
}
.claro .dijitSlider .dijitSliderProgressBarV, .claro .dijitSlider .dijitSliderBottomBumper {
  background-image: url(form/images/sliderVertical.png);
  background-repeat: repeat-y;
  background-position: -36px 0;
  border-color: #b5bcc7;
  background-color: #cfe5fa;
}
.claro .dijitSlider .dijitSliderRemainingBarV, .claro .dijitSlider .dijitSliderTopBumper {
  background-image: url(form/images/sliderVertical.png);
  background-repeat: repeat-y;
  background-position: -3px 0;
  border-color: #b5bcc7;
  background-color: #ffffff;
}
.claro .dijitSliderBottomBumper {
  border-bottom: solid 1px #b5bcc7;
}
.claro .dijitSliderTopBumper {
  border-top: solid 1px #b5bcc7;
}
.claro .dijitSliderHover .dijitSliderProgressBarV, .claro .dijitSliderHover .dijitSliderBottomBumper {
  background-position: -36px 0;
  background-color: #abd6ff;
}
.claro .dijitSliderHover .dijitSliderRemainingBarV, .claro .dijitSliderHover .dijitSliderTopBumper {
  background-position: 0 0;
  background-color: #ffffff;
}
.claro .dijitSliderFocused .dijitSliderProgressBarV, .claro .dijitSliderFocused .dijitSliderBottomBumper {
  background-position: -56px 0;
  background-color: #abd6ff;
}
.claro .dijitSliderFocused .dijitSliderRemainingBarV, .claro .dijitSliderFocused .dijitSliderTopBumper {
  background-position: -18px 0;
  background-color: #ffffff;
}
.claro .dijitSliderDisabled .dijitSliderProgressBarV, .claro .dijitSliderDisabled .dijitSliderBottomBumper {
  background-color: #d3d3d3;
  
}
.claro .dijitSliderDisabled .dijitSliderRemainingBarV, .claro .dijitSliderDisabled .dijitSliderTopBumper {
  background-color: #efefef;
}
.claro .dijitSliderImageHandleH {
  border: 0;
  width: 18px;
  height: 16px;
  background-image: url(form/images/sliderThumbs.png);
  background-repeat: no-repeat;
  background-position: 0 0;
}
.claro .dijitSliderHover .dijitSliderImageHandleH {
  background-position: -18px 0;
}
.claro .dijitSliderFocused .dijitSliderImageHandleH {
  background-position: -36px 0;
}
.claro .dijitSliderProgressBarH .dijitSliderThumbHover {
  background-position: -36px 0;
}
.claro .dijitSliderProgressBarH .dijitSliderThumbActive {
  background-position: -36px 0;
}
.claro .dijitSliderReadOnly .dijitSliderImageHandleH, .claro .dijitSliderDisabled .dijitSliderImageHandleH {
  background-position: -54px 0;
}
.claro .dijitSliderImageHandleV {
  border: 0;
  width: 18px;
  height: 16px;
  background-image: url(form/images/sliderThumbs.png);
  background-repeat: no-repeat;
  background-position: -289px 0;
}
.claro .dijitSliderHover .dijitSliderImageHandleV {
  background-position: -307px 0;
}
.claro .dijitSliderFocused .dijitSliderImageHandleV {
  background-position: -325px 0;
}
.claro .dijitSliderProgressBarV .dijitSliderThumbHover {
  background-position: -325px 0;
}
.claro .dijitSliderProgressBarV .dijitSliderThumbActive {
  background-position: -325px 0;
}
.claro .dijitSliderReadOnly .dijitSliderImageHandleV, .claro .dijitSliderDisabled .dijitSliderImageHandleV {
  background-position: -343px 0;
}
.claro .dijitSliderButtonContainerH {
  padding: 1px 3px 1px 2px;
}
.claro .dijitSliderButtonContainerV {
  padding: 3px 1px 2px 1px;
}
.claro .dijitSliderDecrementIconH,
.claro .dijitSliderIncrementIconH,
.claro .dijitSliderDecrementIconV,
.claro .dijitSliderIncrementIconV {
  background-image: url(form/images/commonFormArrows.png);
  background-repeat: no-repeat;
  background-color: #efefef;
  -moz-border-radius: 2px;
  border-radius: 2px;
  border: solid 1px #b5bcc7;
  font-size: 1px;
}
.claro .dijitSliderDecrementIconH, .claro .dijitSliderIncrementIconH {
  height: 12px;
  width: 9px;
}
.claro .dijitSliderDecrementIconV, .claro .dijitSliderIncrementIconV {
  height: 9px;
  width: 12px;
}
.claro .dijitSliderActive .dijitSliderDecrementIconH,
.claro .dijitSliderActive .dijitSliderIncrementIconH,
.claro .dijitSliderActive .dijitSliderDecrementIconV,
.claro .dijitSliderActive .dijitSliderIncrementIconV,
.claro .dijitSliderHover .dijitSliderDecrementIconH,
.claro .dijitSliderHover .dijitSliderIncrementIconH,
.claro .dijitSliderHover .dijitSliderDecrementIconV,
.claro .dijitSliderHover .dijitSliderIncrementIconV {
  
  border: solid 1px #759dc0;
  background-color: #ffffff;
}
.claro .dijitSliderDecrementIconH {
  background-position: -357px 50%;
}
.claro .dijitSliderActive .dijitSliderDecrementIconH.claro .dijitSliderHover .dijitSliderDecrementIconH {
  background-position: -393px 50%;
}
.claro .dijitSliderIncrementIconH {
  background-position: -251px 50%;
}
.claro .dijitSliderActive .dijitSliderIncrementIconH.claro .dijitSliderHover .dijitSliderIncrementIconH {
  background-position: -283px 50%;
}
.claro .dijitSliderDecrementIconV {
  background-position: -38px 50%;
}
.claro .dijitSliderActive .dijitSliderDecrementIconV.claro .dijitSliderHover .dijitSliderDecrementIconV {
  background-position: -73px 50%;
}
.claro .dijitSliderIncrementIconV {
  background-position: -143px 49%;
}
.claro .dijitSliderActive .dijitSliderIncrementIconV.claro .dijitSliderHover .dijitSliderIncrementIconV {
  background-position: -178px 49%;
}
.claro .dijitSliderButtonContainerV .dijitSliderDecrementButtonHover,
.claro .dijitSliderButtonContainerH .dijitSliderDecrementButtonHover,
.claro .dijitSliderButtonContainerV .dijitSliderIncrementButtonHover,
.claro .dijitSliderButtonContainerH .dijitSliderIncrementButtonHover {
  background-color: #cfe5fa;
}
.claro .dijitSliderButtonContainerV .dijitSliderDecrementButtonActive,
.claro .dijitSliderButtonContainerH .dijitSliderDecrementButtonActive,
.claro .dijitSliderButtonContainerV .dijitSliderIncrementButtonActive,
.claro .dijitSliderButtonContainerH .dijitSliderIncrementButtonActive {
  background-color: #abd6ff;
  border-color: #759dc0;
}
.claro .dijitSliderButtonInner {
  visibility: hidden;
}
.claro .dijitSliderDisabled .dijitSliderBar {
  border-color: #d3d3d3;
}
.claro .dijitSliderReadOnly *, .claro .dijitSliderDisabled * {
  border-color: #d3d3d3;
  color: #818181;
}
.claro .dijitSliderReadOnly .dijitSliderDecrementIconH, .claro .dijitSliderDisabled .dijitSliderDecrementIconH {
  background-position: -321px 50%;
  background-color: #efefef;
}
.claro .dijitSliderReadOnly .dijitSliderIncrementIconH, .claro .dijitSliderDisabled .dijitSliderIncrementIconH {
  background-position: -215px 50%;
  background-color: #efefef;
}
.claro .dijitSliderReadOnly .dijitSliderDecrementIconV, .claro .dijitSliderDisabled .dijitSliderDecrementIconV {
  background-position: -3px 49%;
  background-color: #efefef;
}
.claro .dijitSliderReadOnly .dijitSliderIncrementIconV, .claro .dijitSliderDisabled .dijitSliderIncrementIconV {
  background-position: -107px 49%;
  background-color: #efefef;
}
.dj_ie6 .claro .dijitSlider .dijitSliderProgressBarH,
.dj_ie6 .claro .dijitSlider .dijitSliderLeftBumper,
.dj_ie6 .claro .dijitSlider .dijitSliderRemainingBarH,
.dj_ie6 .claro .dijitSlider .dijitSliderRightBumper,
.dj_ie6 .claro .dijitSlider .dijitSliderProgressBarV,
.dj_ie6 .claro .dijitSlider .dijitSliderTopBumper,
.dj_ie6 .claro .dijitSlider .dijitSliderRemainingBarV,
.dj_ie6 .claro .dijitSlider .dijitSliderBottomBumper {
  background-image: none;
}
.claro  .dijitColorPalette {
  border: 1px solid #b5bcc7;
  background: #ffffff;
  -moz-border-radius: 0;
  border-radius: 0;
}
.claro .dijitColorPalette .dijitPaletteImg {
  
  border: 1px solid #d3d3d3;
}
.claro .dijitColorPalette .dijitPaletteCell:hover .dijitPaletteImg {
  border: 1px solid #000000;
}
.claro .dijitColorPalette .dijitPaletteCell:active .dijitPaletteImg, .claro .dijitColorPalette .dijitPaletteTable .dijitPaletteCellSelected .dijitPaletteImg {
  border: 2px solid #000000;
}
.claro .dijitInlineEditBoxDisplayMode {
  border: 1px solid transparent;
}
.claro .dijitInlineEditBoxDisplayModeHover {
  background-color: #e5f2fe;
  border: solid 1px #759dc0;
}
.dj_ie6 .claro .dijitInlineEditBoxDisplayMode {
  border: none;
}
.claro .dijitProgressBar {
  margin: 2px 0 2px 0;
}
.claro .dijitProgressBarEmpty {
  
  background: #ffffff url(images/progressBarEmpty.png) no-repeat left;
  border-color: #759dc0;
}
.claro .dijitProgressBarTile {
  
  background: #abd6ff url(images/progressBarFull.png) repeat-x top;
}
.dj_ie6 .claro .dijitProgressBarTile {
  background-image: none;
}
.claro .dijitProgressBarFull {
  border-right: 1px solid #759dc0;
  -webkit-transition-property: width;
  -moz-transition-property: width;
  transition-property: width;
  -webkit-transition-duration: 0.25s;
  -moz-transition-duration: 0.25s;
  transition-duration: 0.25s;
}
.claro .dijitProgressBarLabel {
  
  color: #000000;
}
.claro .dijitProgressBarIndeterminate .dijitProgressBarTile {
  
  background: #efefef url(images/progressBarAnim.gif) repeat-x top;
}
.claro .dijitTimePicker .dijitButtonNode {
  padding: 0 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.claro .dijitTimePicker {
  border: 1px #b5bcc7 solid;
  border-top: none;
  border-bottom: none;
  background-color: #fff;
  
}
.claro .dijitTimePickerItem {
  
  background-image: url(images/commonHighlight.png);
  background-position: 0 -1px;
  background-repeat: repeat-x;
  border-top: solid 1px #b5bcc7;
  border-bottom: solid 1px #b5bcc7;
  margin-right: -1px;
  margin-left: -1px;
  margin-top: -1px;
}
.dj_ie6 .claro .dijitTimePickerItem {
  background-image: none;
}
.claro .dijitTimePickerTick {
  
  color: #818181;
  background-color: #efefef;
  font-size: 0.818em;
}
.claro .dijitTimePickerMarker {
  
  background-color: #e5f2fe;
  font-size: 1em;
  white-space: nowrap;
}
.claro .dijitTimePickerTickHover,
.claro .dijitTimePickerMarkerHover,
.claro .dijitTimePickerMarkerSelected,
.claro .dijitTimePickerTickSelected {
  background-color: #7dbdfa;
  border: solid 1px #b5bcc7;
  margin-left: -7px;
  margin-right: -7px;
  color: #000000;
}
.claro .dijitTimePickerMarkerSelected, .claro .dijitTimePickerTickSelected {
  font-size: 1em;
}
.dj_ie .claro .dijitTimePickerTickHover,
.dj_ie .claro .dijitTimePickerMarkerHover,
.dj_ie .claro .dijitTimePickerMarkerSelected,
.dj_ie .claro .dijitTimePickerTickSelected {
  width: 114%;
}
.dj_ie6 .claro .dijitTimePickerTickHover,
.dj_ie6 .claro .dijitTimePickerMarkerHover,
.dj_ie6 .claro .dijitTimePickerMarkerSelected,
.dj_ie6 .claro .dijitTimePickerTickSelected {
  position: relative;
  
  zoom: 1;
  
}
.claro .dijitTimePickerTick .dijitTimePickerItemInner {
  padding: 1px;
  margin: 0;
}
.claro .dijitTimePicker .dijitButtonNode {
  border-left: none;
  border-right: none;
  border-color: #b5bcc7;
  background-color: #efefef;
  background-image: url(images/commonHighlight.png);
  background-position: 0 -1px;
  background-repeat: repeat-x;
}
.dj_ie6 .claro .dijitTimePicker .dijitButtonNode {
  background-image: none;
}
.claro .dijitTimePicker .dijitArrowButtonInner {
  height: 100%;
  
  background-image: url(form/images/commonFormArrows.png);
  background-repeat: no-repeat;
  background-position: -140px 45%;
}
.claro .dijitTimePicker .dijitDownArrowButton .dijitArrowButtonInner {
  background-position: -35px 45%;
}
.claro .dijitTimePicker .dijitUpArrowHover, .claro .dijitTimePicker .dijitDownArrowHover {
  background-color: #abd6ff;
}
.claro .dijitTimePicker .dijitUpArrowHover .dijitArrowButtonInner {
  background-position: -175px 45%;
}
.claro .dijitTimePicker .dijitDownArrowHover .dijitArrowButtonInner {
  background-position: -70px 45%;
}
.claro .dijitBorderContainer {
  
  padding: 5px;
}
.claro .dijitSplitContainer-child, .claro .dijitBorderContainer-child {
  
  border: 1px #b5bcc7 solid;
}
.claro .dijitBorderContainer-dijitTabContainerTop,
.claro .dijitBorderContainer-dijitTabContainerBottom,
.claro .dijitBorderContainer-dijitTabContainerLeft,
.claro .dijitBorderContainer-dijitTabContainerRight,
.claro .dijitBorderContainer-dijitAccordionContainer {
  
  border: none;
}
.claro .dijitBorderContainer-dijitBorderContainer {
  
  border: 0;
  padding: 0;
}
.claro .dijitSplitterH, .claro .dijitGutterH {
  background: none;
  border: 0;
  height: 5px;
}
.claro .dijitSplitterH .dijitSplitterThumb {
  background: #b5bcc7 none;
  height: 1px;
  top: 2px;
  width: 19px;
}
.claro .dijitSplitterV, .claro .dijitGutterV {
  background: none;
  border: 0;
  width: 5px;
  margin: 0;
}
.claro .dijitSplitterV .dijitSplitterThumb {
  background: #b5bcc7 none;
  height: 19px;
  left: 2px;
  width: 1px;
  margin: 0;
}
.claro .dijitSplitterHHover {
  font-size: 1px;
  background: url(layout/images/splitterHorizontalHover.png) no-repeat center top;
}
.claro .dijitSplitterHHover .dijitSplitterThumb {
  background: #759dc0 none;
}
.claro .dijitSplitterVHover {
  font-size: 1px;
  background: url(layout/images/splitterVerticalHover.png) no-repeat center left;
}
.claro .dijitSplitterVHover .dijitSplitterThumb {
  background: #759dc0 none;
}
.dj_ie6 .dijitSplitterHHover, .dj_ie6 .claro .dijitSplitterVHover {
  background-color: #cfe5fa;
  background-image: none;
}
.claro .dijitSplitterHActive, .claro .dijitSplitterVActive {
  font-size: 1px;
  background-color: #abd6ff;
}
.claro .dijitTreeNode {
  zoom: 1;
  
}
.claro .dijitTreeIsRoot {
  background-image: none;
}
.claro .dijitTreeRow, .claro .dijitTreeNode .dojoDndItemBefore, .claro .dijitTreeNode .dojoDndItemAfter {
  
  padding: 4px 1px 2px 0;
  margin: 0 1px;
  
  background-color: none;
  background-color: transparent;
  background-color: rgba(171, 214, 255, 0);
  background-position: 0 0;
  background-repeat: repeat-x;
  border-color: rgba(118, 157, 192, 0);
  border-width: 0;
  color: #000000;
  -webkit-transition-property: background-color, border-color;
  -moz-transition-property: background-color, border-color;
  transition-property: background-color, border-color;
  -webkit-transition-duration: 0.25s;
  -moz-transition-duration: 0.25s;
  transition-duration: 0.25s;
  -webkit-transition-timing-function: ease-out;
  -moz-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
}
.claro .dijitTreeRowSelected {
  background-repeat: repeat-x;
  background-color: #cfe5fa;
  background-image: url(images/commonHighlight.png);
  padding: 3px 0 1px;
  margin: 0;
  border: solid 1px #759dc0;
  color: #000000;
}
.claro .dijitTreeRowHover {
  background-color: #abd6ff;
  background-image: url(images/commonHighlight.png);
  padding: 3px 0 1px;
  margin: 0;
  border: solid 1px #759dc0;
  color: #000000;
  -webkit-transition-duration: 0.25s;
  -moz-transition-duration: 0.25s;
  transition-duration: 0.25s;
}
.claro .dijitTreeRowActive {
  background-color: #7dbdfa;
  background-image: url(images/commonHighlight.png);
  background-position: 0 -177px;
  padding: 3px 0 1px;
  margin-left: 0;
  border: solid 1px #759dc0;
  color: #000000;
}
.dj_ie6 .claro .dijitTreeRow {
  background-image: none;
}
.claro .dijitTreeRowFocused {
  background-repeat: repeat;
}
.claro .dijitTreeExpando {
  background-image: url(images/treeExpandImages.png);
  width: 16px;
  height: 16px;
  background-position: -35px 0;
  
}
.dj_ie6 .claro .dijitTreeExpando {
  background-image: url(images/treeExpandImages8bit.png);
}
.claro .dijitTreeRowHover .dijitTreeExpandoOpened {
  background-position: -53px 0;
}
.claro .dijitTreeExpandoClosed {
  background-position: 1px 0;
}
.claro .dijitTreeRowHover .dijitTreeExpandoClosed {
  background-position: -17px 0;
}
.claro .dijitTreeExpandoLeaf, .dj_ie6 .claro .dijitTreeExpandoLeaf {
  background-image: none;
}
.claro .dijitTreeExpandoLoading {
  background-image: url(images/loadingAnimation.gif);
}
.claro .dijitTreeNode .dojoDndItemBefore .dijitTreeContent {
  border-top: 2px solid #759dc0;
}
.claro .dijitTreeNode .dojoDndItemAfter .dijitTreeContent {
  border-bottom: 2px solid #759dc0;
}
 
.claro .dijitToolbar {
  border-bottom: 1px solid #b5bcc7;
  background-color: #efefef;
  background-image: url(images/commonHighlight.png);
  background-position: 0 0;
  background-repeat: repeat-x;
  padding: 2px 0 2px 4px;
  zoom: 1;
}
.claro .dijitToolbar label {
  padding: 0 3px 0 6px;
}
.claro .dijitToolbar .dijitButton .dijitButtonNode,
.claro .dijitToolbar .dijitDropDownButton .dijitButtonNode,
.claro .dijitToolbar .dijitComboButton .dijitButtonNode,
.claro .dijitToolbar .dijitToggleButton .dijitButtonNode,
.claro .dijitToolbar .dijitComboBox .dijitButtonNode {
  border-width: 0;
  
  padding: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  -webkit-transition-property: background-color;
  -moz-transition-property: background-color;
  transition-property: background-color;
  -webkit-transition-duration: 0.3s, 0.35s;
  -moz-transition-duration: 0.3s, 0.35s;
  transition-duration: 0.3s, 0.35s;
  background-image: url(images/commonHighlight.png);
  background-position: 0 -30px;
  background-repeat: repeat-x;
  background-color: rgba(171, 214, 255, 0);
}
.dj_ie .claro .dijitToolbar .dijitButton .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitDropDownButton .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitComboButton .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitToggleButton .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitComboBox .dijitButtonNode {
  background-color: transparent;
  
}
.dj_ie6 .claro .dijitToolbar .dijitButton .dijitButtonNode,
.dj_ie6 .claro .dijitToolbar .dijitDropDownButton .dijitButtonNode,
.dj_ie6 .claro .dijitToolbar .dijitComboButton .dijitButtonNode,
.dj_ie6 .claro .dijitToolbar .dijitToggleButton .dijitButtonNode,
.dj_ie6 .claro .dijitToolbar .dijitComboBox .dijitButtonNode {
  background: none;
  
}
.dj_ie .claro .dijitToolbar .dijitButtonHover .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitDropDownButtonHover .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitComboButton .dijitButtonNodeHover,
.dj_ie .claro .dijitToolbar .dijitComboButton .dijitDownArrowButtonHover,
.dj_ie .claro .dijitToolbar .dijitToggleButtonHover .dijitButtonNode {
  
  background-color: #abd6ff;
}
.dj_ie .claro .dijitToolbar .dijitButtonActive .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitDropDownButtonActive .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitComboButtonActive .dijitButtonNode,
.dj_ie .claro .dijitToolbar .dijitToggleButtonActive .dijitButtonNode {
  
  background-color: #abd6ff;
}
.claro .dijitToolbar .dijitComboButton .dijitStretch {
  
  -moz-border-radius: 2px 0 0 2px;
  border-radius: 2px 0 0 2px;
}
.claro .dijitToolbar .dijitComboButton .dijitArrowButton {
  
  -moz-border-radius: 0 2px 2px 0;
  border-radius: 0 2px 2px 0;
}
.claro .dijitToolbar .dijitComboBox .dijitButtonNode {
  padding: 0;
}
.claro .dijitToolbar .dijitButtonHover .dijitButtonNode,
.claro .dijitToolbar .dijitDropDownButtonHover .dijitButtonNode,
.claro .dijitToolbar .dijitToggleButtonHover .dijitButtonNode,
.claro .dijitToolbar .dijitComboButtonHover .dijitButtonNode {
  background-position: 0 0;
  border-width: 1px;
  background-color: #abd6ff;
  padding: 1px;
}
.claro .dijitToolbar .dijitComboButtonHover .dijitButtonNode, .claro .dijitToolbar .dijitComboButtonHover .dijitDownArrowButton {
  background-position: 0 0;
  background-color: #f3ffff;
}
.claro .dijitToolbar .dijitComboButtonHover .dijitButtonNodeHover, .claro .dijitToolbar .dijitComboButtonHover .dijitDownArrowButtonHover {
  background-color: #abd6ff;
}
.claro .dijitToolbar .dijitButtonActive .dijitButtonNode, .claro .dijitToolbar .dijitDropDownButtonActive .dijitButtonNode, .claro .dijitToolbar .dijitToggleButtonActive .dijitButtonNode {
  border-width: 1px;
  background-color: #7dbdfa;
  background-position: 0 -177px;
  padding: 1px;
}
.claro .dijitToolbar .dijitComboButtonActive {
  -webkit-transition-duration: 0.2s;
  -moz-transition-duration: 0.2s;
  transition-duration: 0.2s;
  border-width: 1px;
  padding: 0;
}
.claro .dijitToolbar .dijitComboButtonActive .dijitButtonNode, .claro .dijitToolbar .dijitComboButtonActive .dijitDownArrowButton {
  background-color: #f3ffff;
  background-position: 0 -177px;
  padding: 2px;
}
.claro .dijitToolbar .dijitComboButtonActive .dijitButtonNodeActive {
  background-color: #7dbdfa;
}
.claro .dijitToolbar .dijitComboButtonActive .dijitDownArrowButtonActive {
  background-color: #7dbdfa;
}
.claro .dijitToolbar .dijitComboButtonHover .dijitDownArrowButton, .claro .dijitToolbar .dijitComboButtonActive .dijitDownArrowButton {
  border-left-width: 0;
}
.claro .dijitToolbar .dijitComboButtonHover .dijitDownArrowButton {
  padding-left: 2px;
  
}
.claro .dijitToolbar .dijitToggleButtonChecked .dijitButtonNode {
  margin: 0;
  
  border-width: 1px;
  border-style: solid;
  background-image: none;
  border-color: #759dc0;
  background-color: #ffffff;
  padding: 1px;
}
.dj_ie6 .claro .dijitToolbar {
  background-image: none;
}
.claro .dijitToolbarSeparator {
  
  background: url(../../icons/images/editorIconsEnabled.png);
}
.claro .dijitDisabled .dijitToolbar {
  background: none;
  background-color: #efefef;
  border-bottom: 1px solid #d3d3d3;
}
.claro .dijitToolbar .dijitComboBoxDisabled .dijitArrowButtonInner {
  background-position: 0 50%;
}
.claro .dijitEditorIFrameContainer {
  padding: 3px 3px 1px 10px;
}
.claro .dijitEditorIFrame {
  background-color: #ffffff;
}
.claro .dijitEditor {
  border: 1px solid #b5bcc7;
}
.claro .dijitEditor .dijitEditorIFrameContainer {
  background-color: #ffffff;
  background-image: url(form/images/textBox_back.png);
  background-repeat: repeat-x;
}
.dj_ie6 .claro .dijitEditor .dijitEditorIFrameContainer {
  background-image: none;
}
.claro .dijitEditorHover .dijitEditorIFrameContainer, .claro .dijitEditorHover .dijitEditorIFrameContainer .dijitEditorIFrame {
  background-color: #e5f2fe;
}
.claro .dijitEditorFocused .dijitEditorIFrameContainer, .claro .dijitEditorFocused .dijitEditorIFrameContainer .dijitEditorIFrame {
  
  background-color: #ffffff;
}
.claro .dijitEditorDisabled {
  border: 1px solid #d3d3d3;
  color: #818181;
}
.claro .dijitDisabled .dijitEditorIFrame, .claro .dijitDisabled .dijitEditorIFrameContainer, .claro .dijitDisabled .dijitEditorIFrameContainer .dijitEditorIFrame {
  background-color: #efefef;
  background-image: none;
}
.dijitEditorIcon {
	background-image: url(../../icons/images/editorIconsEnabled.png); 
	background-repeat: no-repeat;
	width: 18px;
	height: 18px;
	text-align: center;
}
.dijitDisabled .dijitEditorIcon {
	background-image: url(../../icons/images/editorIconsDisabled.png); 
}
.dijitEditorIconSep { background-position: 0; }
.dijitEditorIconSave { background-position: -18px; }
.dijitEditorIconPrint { background-position: -36px; }
.dijitEditorIconCut { background-position: -54px; }
.dijitEditorIconCopy { background-position: -72px; }
.dijitEditorIconPaste { background-position: -90px; }
.dijitEditorIconDelete { background-position: -108px; }
.dijitEditorIconCancel { background-position: -126px; }
.dijitEditorIconUndo { background-position: -144px; }
.dijitEditorIconRedo { background-position: -162px; }
.dijitEditorIconSelectAll { background-position: -180px; }
.dijitEditorIconBold { background-position: -198px; }
.dijitEditorIconItalic { background-position: -216px; }
.dijitEditorIconUnderline { background-position: -234px; }
.dijitEditorIconStrikethrough { background-position: -252px; }
.dijitEditorIconSuperscript { background-position: -270px; }
.dijitEditorIconSubscript { background-position: -288px; }
.dijitEditorIconJustifyCenter { background-position: -306px; }
.dijitEditorIconJustifyFull { background-position: -324px; }
.dijitEditorIconJustifyLeft { background-position: -342px; }
.dijitEditorIconJustifyRight { background-position: -360px; }
.dijitEditorIconIndent { background-position: -378px; }
.dijitEditorIconOutdent { background-position: -396px; }
.dijitEditorIconListBulletIndent { background-position: -414px; }
.dijitEditorIconListBulletOutdent { background-position: -432px; }
.dijitEditorIconListNumIndent { background-position: -450px; }
.dijitEditorIconListNumOutdent { background-position: -468px; }
.dijitEditorIconTabIndent { background-position: -486px; }
.dijitEditorIconLeftToRight { background-position: -504px; }
.dijitEditorIconRightToLeft, .dijitEditorIconToggleDir { background-position: -522px; }
.dijitEditorIconBackColor { background-position: -540px; }
.dijitEditorIconForeColor { background-position: -558px; }
.dijitEditorIconHiliteColor { background-position: -576px; }
.dijitEditorIconNewPage { background-position: -594px; }
.dijitEditorIconInsertImage { background-position: -612px; }
.dijitEditorIconInsertTable { background-position: -630px; }
.dijitEditorIconSpace { background-position: -648px; }
.dijitEditorIconInsertHorizontalRule { background-position: -666px; }
.dijitEditorIconInsertOrderedList { background-position: -684px; }
.dijitEditorIconInsertUnorderedList { background-position: -702px; }
.dijitEditorIconCreateLink { background-position: -720px; }
.dijitEditorIconUnlink { background-position: -738px; }
.dijitEditorIconViewSource { background-position: -756px; }
.dijitEditorIconRemoveFormat { background-position: -774px; }
.dijitEditorIconFullScreen { background-position: -792px; }
.dijitEditorIconWikiword { background-position: -810px; }
 
.claro .dijitTitlePaneTitle {
  background-color: #efefef;
  background-image: url(images/titlebar.png);
  background-repeat: repeat-x;
  border: 1px solid #b5bcc7;
  padding: 0 7px 3px 7px;
  min-height: 17px;
}
.dj_ie6 .claro .dijitTitlePaneTitle {
  background-image: none;
}
.claro .dijitTitlePaneTitleHover {
  background-color: #abd6ff;
  border-color: #759dc0;
}
.claro .dijitTitlePaneTitleActive {
  background-color: #7dbdfa;
  border-color: #759dc0;
  background-position: 0 -136px;
}
.claro .dijitTitlePaneTitleFocus {
  margin-top: 3px;
  padding-bottom: 2px;
}
.claro .dijitTitlePane .dijitArrowNode {
  background-image: url(images/spriteArrows.png);
  background-repeat: no-repeat;
  height: 8px;
  width: 7px;
}
.claro .dijitTitlePane .dijitOpen .dijitArrowNode {
  background-position: 0 0;
}
.claro .dijitTitlePane .dijitClosed .dijitArrowNode {
  background-position: -14px 0;
}
.claro .dijitTitlePane .dijitTitlePaneTextNode {
  color: #000000;
}
.claro .dijitTitlePaneContentOuter {
  background: #ffffff;
  border: 1px solid #b5bcc7;
  border-top: none;
}
.claro .dijitTitlePaneContentInner {
  padding: 10px;
}
.claro .dijitTitlePaneTextNode {
  margin-left: 4px;
  margin-right: 4px;
  vertical-align: text-top;
}
.claro .dijitSpinnerButtonContainer {
  overflow: hidden;
  position: relative;
  width: auto;
  padding: 0 2px;
}
.claro .dijitSpinnerButtonContainer .dijitSpinnerButtonInner {
  border-width: 1px 0;
  
  border-style: solid none;
}
.claro .dijitSpinner .dijitArrowButton {
  width: auto;
  background-color: #efefef;
  background-image: url(form/images/formHighlight.png);
  background-position: 0 0;
  background-repeat: repeat-x;
  overflow: hidden;
}
.dj_iequirks .claro .dijitSpinner .dijitArrowButton {
  overflow: visible;
  
}
.claro .dijitSpinner .dijitSpinnerButtonInner {
  width: 15px;
}
.claro .dijitSpinner .dijitArrowButtonInner {
  border: solid 1px #ffffff;
  border-bottom-width: 0;
  
  background-image: url(form/images/commonFormArrows.png);
  background-repeat: no-repeat;
  height: 100%;
  width: 15px;
  padding-left: 1px;
  padding-right: 1px;
  
  background-position: -139px center;
  
  display: block;
  margin: -1px 0 -1px 0;
  
}
.dj_ie6 .claro .dijitSpinner .dijitArrowButtonInner, .dj_ie7 .claro .dijitSpinner .dijitArrowButtonInner {
  margin-top: 0;
  
}
.dj_iequirks .claro .dijitSpinner .dijitArrowButtonInner {
  width: 19px;
}
.claro .dijitSpinner .dijitDownArrowButton .dijitArrowButtonInner {
  background-position: -34px;
}
.claro .dijitSpinner .dijitArrowButtonInner .dijitInputField {
  padding: 0;
}
.claro .dijitUpArrowButtonActive, .claro .dijitDownArrowButtonActive {
  background-color: #abd6ff;
}
.claro .dijitSpinner .dijitUpArrowButtonHover, .claro .dijitSpinner .dijitDownArrowButtonHover, .claro .dijitSpinnerFocused .dijitArrowButton {
  background-color: #abd6ff;
}
.claro .dijitSpinner .dijitUpArrowButtonHover .dijitArrowButtonInner {
  background-position: -174px;
}
.claro .dijitSpinner .dijitDownArrowButtonHover .dijitArrowButtonInner {
  background-position: -69px;
}
.claro .dijitSpinnerFocused {
  background-color: #ffffff;
  background-image: none;
}
.claro .dijitSpinner .dijitDownArrowButtonActive, .claro .dijitSpinner .dijitUpArrowButtonActive {
  background-color: #7dbefa;
  background-position: 0 -177px;
}
.claro .dijitSpinner .dijitUpArrowButtonActive .dijitArrowButtonInner, .claro .dijitSpinner .dijitDownArrowButtonActive .dijitArrowButtonInner {
  
  border: 0;
  padding: 1px;
  margin-right: 2px;
  margin-bottom: 1px;
}
.claro .dijitSpinner .dijitUpArrowButtonActive .dijitArrowButtonInner {
  background-position: -173px;
}
.claro .dijitSpinner .dijitDownArrowButtonActive .dijitArrowButtonInner {
  background-position: -68px;
}
.claro .dijitSpinnerDisabled .dijitArrowButtonInner {
  background-color: #efefef;
}
.claro .dijitSpinnerDisabled .dijitUpArrowButton .dijitArrowButtonInner {
  background-position: -104px;
}
.claro .dijitSpinnerDisabled .dijitDownArrowButton .dijitArrowButtonInner {
  background-position: 1px;
}
.dj_ie7 .claro .dijitSpinner {
  overflow: visible;
}
.dijitRtl .dijitPlaceHolder {
	left: auto;
	right: 0;
}
.dijitMenuItemRtl {
	text-align: right;
}
.dj_iequirks .dijitComboButtonRtl button {
	
	float:left;
}
.dijitTextBoxRtl .dijitValidationContainer,
.dijitTextBoxRtl .dijitSpinnerButtonContainer,
.dijitComboBoxRtl .dijitArrowButtonContainer {
	
	border-right-width: 1px !important;
	border-left-width: 0 !important;
}
.dijitSpinnerRtl .dijitSpinnerButtonContainer .dijitArrowButton {
	right: 0;
	left: auto;
}
.dj_ie7 .dijitInputContainer {
	
	display: inline-block;
}
.dijitTextBoxRtl .dijitSpinnerButtonContainer,
.dijitTextBoxRtl .dijitValidationContainer,
.dijitTextBoxRtl .dijitArrowButtonContainer {
	float: left;
}
.dijitCalendarRtl .dijitCalendarNextYear {
	margin:0 0.55em 0 0;
}
.dijitCalendarRtl .dijitCalendarPreviousYear {
	margin:0 0 0 0.55em;
}
.dijitSliderRtl .dijitSliderImageHandleV {
	left:auto;
}
.dijitSliderRtl .dijitSliderImageHandleH {
	left:-50%;
}
.dijitSliderRtl .dijitSliderMoveableH {
	right:auto;
	left:0;
}
.dijitSliderRtl .dijitRuleContainerV {
	float:right;
}
.dj_ie .dijitSliderRtl .dijitRuleContainerV {
	text-align:right;
}
.dj_ie .dijitSliderRtl .dijitRuleLabelV {
	text-align:left;
}
.dj_ie .dijitSliderRtl .dijitRuleLabelH {
	zoom:1;
}
.dijitSliderRtl .dijitSliderProgressBarH {
	
	float:right;
	right:0;
	left:auto;
}
.dijitRtl .dijitContentPaneLoading .dijitIconLoading,
.dijitRtl .dijitContentPaneError .dijitIconError {
	margin-right: 0;
	margin-left: 9px;
}
.dijitTabControllerRtl .nowrapTabStrip {
    text-align: right;  
}
.dijitTabRtl .dijitTabCloseButton {
	margin-left: 0;
	margin-right: 1em;
}
.dj_ie .dijitTimePickerRtl .dijitTimePickerItem {
	width:100%;
}
.dijitColorPaletteRtl .dijitColorPaletteUnder {
	
	left: auto;
	right: 0;
}
.dijitSelectRtl .dijitButtonContents {
	text-align: right;
}
.claro .dijitTextBoxRtlError .dijitValidationContainer {
  border-left-width: 0;
  border-right-width: 1px;
}
.claro .dijitComboButtonRtl .dijitStretch {
  -moz-border-radius: 0 4px 4px 0;
  border-radius: 0 4px 4px 0;
}
.claro .dijitComboButtonRtl .dijitArrowButton {
  -moz-border-radius: 4px 0 0 4px;
  border-radius: 4px 0 0 4px;
  padding: 3px 0 4px;
  border-left-width: 1px;
  border-right-width: 0;
}
.claro .dijitTabContainerTop-tabs .dijitTabRtl, .claro .dijitTabContainerBottom-tabs .dijitTabRtl {
  margin-right: 0;
  margin-left: 1px;
}
.claro .dijitTabRtl {
  -moz-box-orient: horizontal;
  text-align: right;
}
.dj_ie7 .claro .dijitTabRtl .dijitTabContent {
  display: block;
  left: 0;
}
.dj_ie7 .claro .dijitTabContainerTop-tabs .dijitTabRtl, .dj_ie7 .claro .dijitTabContainerTop-tabs .dijitTabCheckedRtl {
  top: 1px;
}
.dj_ie7 .claro .tabStripButtonRtl .dijitButtonContents,
.dj_ie8 .claro .tabStripButtonRtl .dijitButtonContents,
.dj_ie6 .claro .dijitTabContainerTop-tabs .dijitTabRtl .dijitTabInnerDiv,
.dj_ie6 .claro .dijitTabContainerBottom-tabs .dijitTabRtl .dijitTabInnerDiv,
.dj_ie7 .claro .dijitTabContainerTop-tabs .dijitTabRtl .dijitTabInnerDiv,
.dj_ie7 .claro .dijitTabContainerBottom-tabs .dijitTabRtl .dijitTabInnerDiv,
.dj_iequirks .claro .dijitTabContainerTop-tabs .dijitTabRtl .dijitTabInnerDiv,
.dj_iequirks .claro .dijitTabContainerBottom-tabs .dijitTabRtl .dijitTabInnerDiv {
  float: left;
}
.dj_ie6 .claro .dijitTabRtl .tabLabel,
.dj_ie6 .claro .dijitTabContainerRight-tabs .dijitTabRtl,
.dj_ie6 .claro .dijitTabContainerLeft-tabs .dijitTabRtl,
.dj_ie7 .claro .dijitTabContainerRight-tabs .dijitTabRtl .dijitTabInnerDiv,
.dj_ie7 .claro .dijitTabContainerLeft-tabs .dijitTabRtl .dijitTabInnerDiv {
  
  zoom: 1;
}
.dj_ie6 .claro .dijitTabRtl .dijitTabCloseButton, .dj_ie7 .claro .dijitTabRtl .dijitTabCloseButton, .dj_iequirks .claro .dijitTabRtl .dijitTabCloseButton {
  margin-right: 5px;
}
.dj_ie6 .claro .dijitTabContainerRightRtl .dijitTabContainerRight-tabs, .dj_ie6 .claro .dijitTabContainerLeftRtl .dijitTabContainerLeft-tabs {
  width: 1%;
}
.dj_ie6 .dijitTabContainerTopStrip, .dj_ie6 .dijitTabContainerBottomStrip {
  position: absolute;
}
.dj_iequirks .claro .dijitTabContainerTopRtl .dijitTabContainerTopStrip {
  padding-top: 10px;
}
.dj_ie7 .claro .dijitTabContainerRight-tabs .dijitTabRtlChecked .dijitTabInnerDiv {
  background-position: -341px -179px;
}
.dj_ie6 .dijitTabContainerTopRtl .dijitTabStripIcon, .dj_ie6 .dijitTabContainerBottomRtl .dijitTabStripIcon {
  position: relative;
}
.dj_ie6-rtl .claro .dijitTabContainerTop-tabs {
  
  padding-left: 3px;
}
.dj_iequirks-rtl .claro .dijitTabListWrapper {
  
  border-left: 1px solid #ffffff;
  border-right: 1px solid #ffffff;
}
.claro .dijitSliderRtl .dijitSliderProgressBarH,
.claro .dijitSliderRtl .dijitSliderRemainingBarH,
.claro .dijitSliderRtl .dijitSliderLeftBumper,
.claro .dijitSliderRtl .dijitSliderRightBumper,
.claro .dijitSliderRtl .dijitSliderTopBumper {
  background-position: top right;
}
.claro .dijitSliderRtl .dijitSliderProgressBarV, .claro .dijitSliderRtl .dijitSliderRemainingBarV, .claro .dijitSliderRtl .dijitSliderBottomBumper {
  background-position: bottom right;
}
.claro .dijitSliderRtl .dijitSliderLeftBumper {
  border-left-width: 0;
  border-right-width: 1px;
}
.claro .dijitSliderRtl .dijitSliderRightBumper {
  border-left-width: 1px;
  border-right-width: 0;
}
.claro .dijitSliderRtl .dijitSliderIncrementIconH {
  background-position: -357px 50%;
}
.claro .dijitSliderRtl .dijitSliderDecrementIconH {
  background-position: -251px 50%;
}
.claro .dijitSelectRtl .dijitButtonContents {
  border-right-width: 0;
  border-left-width: 1px;
}
.claro .dijitDialogRtl .dijitDialogCloseIcon {
  right: auto;
  left: 5px;
}
.claro .dijitDialogRtl .dijitDialogPaneActionBar {
  text-align: left;
  padding: 3px 7px 2px 5px;
}
.claro .dijitEditorRtl .dijitEditorIFrameContainer {
  padding: 3px 10px 1px 3px;
}
.dijitEditorRtl .dijitEditorIcon {
	background-image: url(../../icons/images/editorIconsEnabled_rtl.png); 
}
.dijitEditorRtlDisabled .dijitEditorIcon {
	background-image: url(../../icons/images/editorIconsDisabled_rtl.png); 
}
.dijitToolbarRtl .dijitToolbarSeparator {
	background-image: url(../../icons/images/editorIconsEnabled_rtl.png);
}
.dijitRtl .dijitIconSave,
.dijitRtl .dijitIconPrint,
.dijitRtl .dijitIconCut,
.dijitRtl .dijitIconCopy,
.dijitRtl .dijitIconClear,
.dijitRtl .dijitIconDelete,
.dijitRtl .dijitIconUndo,
.dijitRtl .dijitIconEdit,
.dijitRtl .dijitIconNewTask,
.dijitRtl .dijitIconEditTask,
.dijitRtl .dijitIconEditProperty,
.dijitRtl .dijitIconTask,
.dijitRtl .dijitIconFilter,
.dijitRtl .dijitIconConfigure,
.dijitRtl .dijitIconSearch,
.dijitRtl .dijitIconApplication,
.dijitRtl .dijitIconBookmark,
.dijitRtl .dijitIconChart,
.dijitRtl .dijitIconConnector,
.dijitRtl .dijitIconDatabase,
.dijitRtl .dijitIconDocuments,
.dijitRtl .dijitIconMail,
.dijitRtl .dijitLeaf,
.dijitRtl .dijitIconFile,
.dijitRtl .dijitIconFunction,
.dijitRtl .dijitIconKey,
.dijitRtl .dijitIconPackage,
.dijitRtl .dijitIconSample,
.dijitRtl .dijitIconTable,
.dijitRtl .dijitIconUsers,
.dijitRtl .dijitFolderClosed,
.dijitRtl .dijitIconFolderClosed,
.dijitRtl .dijitFolderOpened,
.dijitRtl .dijitIconFolderOpen,
.dijitRtl .dijitIconError { 
	background-image: url(../../icons/images/commonIconsObjActEnabled_rtl.png); 
	width: 16px;
	height: 16px;
}
.dj_ie6 .dijitRtl .dijitIconSave,
.dj_ie6 .dijitRtl .dijitIconPrint,
.dj_ie6 .dijitRtl .dijitIconCut,
.dj_ie6 .dijitRtl .dijitIconCopy,
.dj_ie6 .dijitRtl .dijitIconClear,
.dj_ie6 .dijitRtl .dijitIconDelete,
.dj_ie6 .dijitRtl .dijitIconUndo,
.dj_ie6 .dijitRtl .dijitIconEdit,
.dj_ie6 .dijitRtl .dijitIconNewTask,
.dj_ie6 .dijitRtl .dijitIconEditTask,
.dj_ie6 .dijitRtl .dijitIconEditProperty,
.dj_ie6 .dijitRtl .dijitIconTask,
.dj_ie6 .dijitRtl .dijitIconFilter,
.dj_ie6 .dijitRtl .dijitIconConfigure,
.dj_ie6 .dijitRtl .dijitIconSearch,
.dj_ie6 .dijitRtl .dijitIconApplication,
.dj_ie6 .dijitRtl .dijitIconBookmark,
.dj_ie6 .dijitRtl .dijitIconChart,
.dj_ie6 .dijitRtl .dijitIconConnector,
.dj_ie6 .dijitRtl .dijitIconDatabase,
.dj_ie6 .dijitRtl .dijitIconDocuments,
.dj_ie6 .dijitRtl .dijitIconMail,
.dj_ie6 .dijitRtl .dijitLeaf,
.dj_ie6 .dijitRtl .dijitIconFile,
.dj_ie6 .dijitRtl .dijitIconFunction,
.dj_ie6 .dijitRtl .dijitIconKey,
.dj_ie6 .dijitRtl .dijitIconPackage,
.dj_ie6 .dijitRtl .dijitIconSample,
.dj_ie6 .dijitRtl .dijitIconTable,
.dj_ie6 .dijitRtl .dijitIconUsers,
.dj_ie6 .dijitRtl .dijitFolderClosed,
.dj_ie6 .dijitRtl .dijitIconFolderClosed,
.dj_ie6 .dijitRtl .dijitFolderOpened,
.dj_ie6 .dijitRtl .dijitIconFolderOpen,
.dj_ie6 .dijitRtl .dijitIconError {
	background-image: url(../../icons/images/commonIconsObjActEnabled8bit_rtl.png);
}
.dijitRtl .dijitDisabled .dijitIconSave,
.dijitRtl .dijitDisabled .dijitIconPrint,
.dijitRtl .dijitDisabled .dijitIconCut,
.dijitRtl .dijitDisabled .dijitIconCopy,
.dijitRtl .dijitDisabled .dijitIconClear,
.dijitRtl .dijitDisabled .dijitIconDelete,
.dijitRtl .dijitDisabled .dijitIconUndo,
.dijitRtl .dijitDisabled .dijitIconEdit,
.dijitRtl .dijitDisabled .dijitIconNewTask,
.dijitRtl .dijitDisabled .dijitIconEditTask,
.dijitRtl .dijitDisabled .dijitIconEditProperty,
.dijitRtl .dijitDisabled .dijitIconTask,
.dijitRtl .dijitDisabled .dijitIconFilter,
.dijitRtl .dijitDisabled .dijitIconConfigure,
.dijitRtl .dijitDisabled .dijitIconSearch,
.dijitRtl .dijitDisabled .dijitIconApplication,
.dijitRtl .dijitDisabled .dijitIconBookmark,
.dijitRtl .dijitDisabled .dijitIconChart,
.dijitRtl .dijitDisabled .dijitIconConnector,
.dijitRtl .dijitDisabled .dijitIconDatabase,
.dijitRtl .dijitDisabled .dijitIconDocuments,
.dijitRtl .dijitDisabled .dijitIconMail,
.dijitRtl .dijitDisabled .dijitLeaf,
.dijitRtl .dijitDisabled .dijitIconFile,
.dijitRtl .dijitDisabled .dijitIconFunction,
.dijitRtl .dijitDisabled .dijitIconKey,
.dijitRtl .dijitDisabled .dijitIconPackage,
.dijitRtl .dijitDisabled .dijitIconSample,
.dijitRtl .dijitDisabled .dijitIconTable,
.dijitRtl .dijitDisabled .dijitIconUsers,
.dijitRtl .dijitDisabled .dijitFolderClosed,
.dijitRtl .dijitDisabled .dijitIconFolderClosed,
.dijitRtl .dijitDisabled .dijitFolderOpened,
.dijitRtl .dijitDisabled .dijitIconFolderOpen,
.dijitRtl .dijitDisabled .dijitIconError {
	background-image: url(../../icons/images/commonIconsObjActDisabled_rtl.png); 
}
.claro .dijitTitlePaneRtl .dijitClosed .dijitArrowNode {
  background-position: -7px 0;
}
.claro .dijitMenuItemRtl .dijitMenuExpand {
  background-position: -7px 0;
  margin-right: 0;
  margin-left: 3px;
}
.claro .dijitMenuItemRtl .dijitMenuItemIcon {
  margin: 0 4px 0 0;
}
.claro .dijitCalendarRtl .dijitCalendarIncrease {
  background-position: 0 0;
}
.claro .dijitCalendarRtl .dijitCalendarDecrease {
  background-position: -18px 0;
}
.claro .dijitCalendarRtl .dijitCalendarArrowHover .dijitCalendarIncrease {
  background-position: -36px 0;
}
.claro .dijitCalendarRtl .dijitCalendarArrowHover .dijitCalendarDecrease {
  background-position: -55px 0;
}
.claro .dijitCalendarRtl .dijitCalendarArrowActive .dijitCalendarIncrease {
  background-position: -72px 0;
}
.claro .dijitCalendarRtl .dijitCalendarArrowActive .dijitCalendarDecrease {
  background-position: -91px 0;
}
.dj_ie .claro .dijitTimePickerRtl .dijitTimePickerTickHover,
.dj_ie .claro .dijitTimePickerRtl .dijitTimePickerMarkerHover,
.dj_ie .claro .dijitTimePickerRtl .dijitTimePickerMarkerSelected,
.dj_ie .claro .dijitTimePickerRtl .dijitTimePickerTickSelected {
  margin-left: -6px;
  margin-right: -8px;
  width: 114%;
}
.claro .dijitToolbar .dijitComboButtonRtl .dijitButtonNode {
  border-width: 0;
  padding: 2px;
}
.claro .dijitToolbar .dijitComboButtonRtlHover .dijitButtonNode, .claro .dijitToolbar .dijitComboButtonRtlActive .dijitButtonNode {
  border-width: 1px;
  padding: 1px;
}
.claro .dijitToolbar .dijitComboButtonRtl .dijitStretch {
  
  -moz-border-radius: 0 2px 2px 0;
  border-radius: 0 2px 2px 0;
}
.claro .dijitToolbar .dijitComboButtonRtl .dijitArrowButton {
  
  -moz-border-radius: 2px 0 0 2px;
  border-radius: 2px 0 0 2px;
}
.claro .dijitToolbar .dijitComboButtonRtlHover .dijitArrowButton, .claro .dijitToolbar .dijitComboButtonRtlActive .dijitArrowButton {
  
  border-left-width: 1px;
  border-right-width: 0;
  padding-left: 1px;
  padding-right: 2px;
}
